@@ -217,9 +217,16 @@ QString KommanderWidget::evalAssociatedText(const QString& a_text)
           evalText += evalArrayFunction(function, args);
           break;
         case Group::String:
-          evalText += evalStringFunction(function, args);
+          evalText += Parser::function(internalParserData(), "str_" + function, args);
+          break;
         case Group::File:
-          evalText += evalFileFunction(function, args);
+          evalText += Parser::function(internalParserData(), "file_" + function, args);
+          break;
+        case Group::Message:
+          evalText += Parser::function(internalParserData(), "message_" + function, args);
+          break;
+        case Group::Input:
+          evalText += Parser::function(internalParserData(), "input_" + function, args);
           break;
         default:
           return QString::null;
