@@ -166,8 +166,14 @@ QString Parser::errorMessage()
   
 }
 
-
-
+QString Parser::function(ParserData* data, const QString& name, const QStringList& params)
+{
+  ParameterList par;
+  for (QStringList::ConstIterator Iter = params.begin(); Iter != params.end(); ++Iter)
+    par.append(*Iter);
+  Function f = data->function(name);
+  return f.execute(0, par).toString();
+}
 
   
 QString Parser::expression(Mode mode)
@@ -213,7 +219,7 @@ ParseNode Parser::parseValue(Mode mode)
 {
   ParseNode p = next();
   if (isFunction())
-    return parseFunction();
+    return parseFunction(mode);
   else if (isWidget())
     return parseWidget(mode);
   else if (tryVariable(CheckOnly))
@@ -356,7 +362,7 @@ ParseNode Parser::parseAnd(Mode mode)
 
 ParseNode Parser::parseOr(Mode mode)
 {
-  ParseNode p = parseNot(mode);
+  ParseNode p = parseAnd(mode);
   while (tryKeyword(Or, CheckOnly))
   {
     if (p == true)
