@@ -1,16 +1,24 @@
 #include "kxsldbg_part.h"
+#include "libxsldbg/files.h"
+#include "libxsldbg/xsldbg.h"
 
 #include <kinstance.h>
 #include <kaction.h>
 #include <kstdaction.h>
 #include <kfiledialog.h>
 #include <kparts/genericfactory.h>
+#include <ktexteditor/markinterface.h> 
+#include <ktexteditor/editinterface.h> 
+#include <ktexteditor/viewcursorinterface.h> 
+#include <ktexteditor/configinterface.h>
+#include <kate/view.h> 
 
 #include <qfile.h>
 #include <qtextstream.h>
 
 #include "../kxsldbg.h"
 #include <kaction.h>
+#include <kcmdlineargs.h>
 #include <kinstance.h>
 #include <kiconloader.h>
 #include <qmessagebox.h>
@@ -23,14 +31,13 @@
 #endif
 
 // Qxsldbg specific includes
+#include "qxsldbgdoc.h"
 #include <qvariant.h>
 #include <qfile.h>
 #include <qstatusbar.h>
 #include <qsplitter.h>
 #include <qvbox.h>
 
-#include "qxsldbgdoc.h"
-#include "qxsldbgview.h"
 
 #include <qmime.h>
 #include <qdragobject.h>
@@ -50,6 +57,8 @@
 #include <qdockwindow.h>
 #include <qpushbutton.h>
 #include <qinputdialog.h>
+#include <qobjectlist.h>
+#include <qwidgetstack.h> 
 #include "xsldbgoutputview.h"
 #include "xsldbgconfigimpl.h"
 #include <kdebug.h>
@@ -67,6 +76,7 @@ KXsldbgPart::KXsldbgPart( QWidget *parentWidget, const char * /*widgetName*/,
     inspector = 0L;
     debugger = 0L;
     configWidget = 0L;
+    currentDoc = 0L;
 
     // we need an instance
     setInstance( KXsldbgPartFactory::instance() );
@@ -84,28 +94,25 @@ KXsldbgPart::KXsldbgPart( QWidget *parentWidget, const char * /*widgetName*/,
     evaluateBtn = new QPushButton(i18n("Evaluate"), h);
 
     QSplitter *splitter = new QSplitter(QSplitter::Vertical, frame);
-
-    m_editWidget = new QXsldbgView( splitter);
-    connect(m_editWidget, SIGNAL(cursorPositionChanged(int, int)),
-            this, SLOT(editWidget_cursorPositionChanged(int, int)));
-    connect(m_editWidget,SIGNAL(openFile(QString, int, int)),
-	    this,  SLOT(emitOpenFile(QString, int, int)));
-    m_editWidget->setDocument(0L);
+    mainView = new QWidgetStack(splitter);
     outputview = new XsldbgOutputView(splitter);
     setWidget(frame);
-
-    docDictionary.setAutoDelete(TRUE);
+    docDictionary.setAutoDelete(true);
 
     // create our actions
     KStdAction::open(this, SLOT(fileOpen()), actionCollection());
 
     // set our XML-UI resource file
-    setXMLFile("kxsldbg_part.rc");
+   setXMLFile("kxsldbg_part.rc");
+   (void) new KAction( i18n("Configure Editor..."),
+		       "configure", 0,
+		       this, SLOT(configureEditorCmd_activated()),
+		       actionCollection(), "configureEditorCmd" );
    (void) new KAction( i18n("Configure..."),
                         "configure", Key_C,
                         this, SLOT(configureCmd_activated()),
                         actionCollection(), "configureCmd" );
-
+   
     (void) new KAction( i18n("Inspect..."),
                         "find", Key_I,
                         this, SLOT(inspectorCmd_activated()),
@@ -217,6 +224,10 @@ KXsldbgPart::KXsldbgPart( QWidget *parentWidget, const char * /*widgetName*/,
                         this, SLOT(slotLookupPublicID()),
                         actionCollection(), "lookupPublicID" );
 
+    (void) new KAction( i18n("Quit"),
+                        0, CTRL + Key_Q,
+                        this, SLOT(quit()),
+                        actionCollection(), "file_quit" );
 
     /*
     (void) new KAction( i18n("Exit KXsldbg"),
@@ -233,12 +244,26 @@ KXsldbgPart::KXsldbgPart( QWidget *parentWidget, const char * /*widgetName*/,
     connect( searchBtn, SIGNAL( clicked() ),
              this, SLOT( slotSearch() ) );
 */
-
+/* We must have a valid debugger and inspector */
+    createInspector();
+    if (checkDebugger()){
+	configWidget = new XsldbgConfigImpl( debugger, 0L );
+	Q_CHECK_PTR( configWidget );
+	debugger->start();
+    }else{
+	openURL("");
+    }
 }
 
-
 KXsldbgPart::~KXsldbgPart()
 {
+    docDictionary.clear();
+}
+
+void KXsldbgPart::quit()
+{
+    qWarning("Custom void KXsldbgPart::quit()");
+    closeURL();
 }
 
 
@@ -248,35 +273,61 @@ KAboutData *KXsldbgPart::createAboutData()
     // which the part's rc file is installed ('partrcdir' in the
     // Makefile)
     KAboutData *aboutData = new KAboutData("kxsldbgpart", I18N_NOOP("KXsldbgPart"), "0.1");
-    aboutData->addAuthor("Keith Isdale", 0, "k_isdale@tpg.com.au");
+    aboutData->addAuthor("Keith Isdale", 0L, "k_isdale@tpg.com.au");
     return aboutData;
 }
 
-bool KXsldbgPart::openFile()
+
+bool  KXsldbgPart::openURL(const KURL &url)
 {
-    // m_file is always local so we can use QFile on it
-    QFile file(m_file);
-    if (file.open(IO_ReadOnly) == false)
-        return false;
+    bool result = fetchURL(url);
+    if (result){
+	QXsldbgDoc *docPtr = docDictionary[url.prettyURL()];
+	if (docPtr && docPtr->kateView()){
+	    if (docPtr != currentDoc){
+		currentDoc = docPtr;
+		currentFileName = url.prettyURL();
+		mainView->raiseWidget(currentDoc->kateView());
+		emit setWindowCaption(currentDoc->url().prettyURL()); 
+	    }
+	} else{
+	    result = false;
+	}
+    }
+    
+    return result;
+}
 
-    // our example widget is text-based, so we use QTextStream instead
-    // of a raw QDataStream
-    QTextStream stream(&file);
-    QString str;
-    while (!stream.eof())
-        str += stream.readLine() + "\n";
 
-    file.close();
-
-    // now that we have the entire file, display it
-    // widget()->setText(str);
-
-    // just for fun, set the status bar
-    emit setStatusBarText( m_url.prettyURL() );
+/* Don't show the content of URL just loaded it into our data structures */
+bool  KXsldbgPart::fetchURL(const KURL &url)
+{
+    QString docID = url.prettyURL();
+    QXsldbgDoc *docPtr = docDictionary[docID]; 
+    if (!docPtr){
+	docPtr = new QXsldbgDoc(mainView, url);
+	docDictionary.insert(docID, docPtr);
+	if (docPtr->kateView()){
+		mainView->addWidget(docPtr->kateView());
+		Kate::View *v = Kate::view((docPtr->kateView()));   
+		connect(v, SIGNAL(cursorPositionChanged()), this, SLOT(cursorPositionChanged()));  
+	}
+    }
 
     return true;
 }
 
+bool KXsldbgPart::openFile()
+{
+    qWarning("bool KXsldbgPart::openFile() called");
+    return false;
+}
+
+bool KXsldbgPart::closeURL()
+{
+    docDictionary.clear();
+    return true;
+}
 
 void KXsldbgPart::fileOpen()
 {
@@ -289,6 +340,14 @@ void KXsldbgPart::fileOpen()
         openURL(KURL( file_name ));
 }
 
+void KXsldbgPart::configureEditorCmd_activated()
+{
+    if (currentDoc){
+	KTextEditor::ConfigInterface *configIf = KTextEditor::configInterface(currentDoc->kateDoc());
+	if (configIf)
+	    configIf->configDialog();
+    }
+}
 
 bool KXsldbgPart::checkDebugger()
 {
@@ -315,13 +374,13 @@ void KXsldbgPart::lookupSystemID( QString systemID)
 			      i18n( "Lookup SystemID" ),
 			      i18n( "Please enter SystemID to find:" ),
 			      QString::null, &ok,
-			      m_editWidget);
+			      mainView);
 #else
      systemID = QInputDialog::getText(
 			      i18n( "Lookup SystemID" ),
 			      i18n( "Please enter SystemID to find:" ),
 			      QLineEdit::Normal, QString::null, &ok,
-			      m_editWidget);
+			      mainView);
 #endif
    }else{
      ok = TRUE;
@@ -346,12 +405,12 @@ void KXsldbgPart::lookupPublicID(QString publicID)
      publicID = KInputDialog::getText(
 			      i18n( "Lookup PublicID" ),
 			      i18n( "Please enter PublicID to find:" ),
-			      QString::null, &ok, m_editWidget );
+			      QString::null, &ok, mainView );
 #else
      publicID = QInputDialog::getText(
 			      i18n( "Lookup PublicID" ),
 			      i18n( "Please enter PublicID to find:" ),
-			      QLineEdit::Normal, QString::null, &ok, m_editWidget );
+			      QLineEdit::Normal, QString::null, &ok, mainView );
 #endif
    }else{
      ok = TRUE;
@@ -376,22 +435,13 @@ void KXsldbgPart::slotLookupPublicID()
 
 void KXsldbgPart::configureCmd_activated()
 {
-  if (debugger == 0L){
-    /* We must have a valid debugger */
-    if (inspector == 0L){
-      createInspector();
-    }
-    if (!checkDebugger())
-      return;
-  }
+  if (!checkDebugger())
+    return;
 
-  if (configWidget == 0L){
-    configWidget = new XsldbgConfigImpl( debugger, 0L );
-    Q_CHECK_PTR( configWidget );
-  }
-  if (configWidget != 0L)
+  if (configWidget != 0L){
     configWidget->refresh();
     configWidget->show();
+  }
 }
 
 void
@@ -418,6 +468,8 @@ void KXsldbgPart::createInspector()
       debugger = new XsldbgDebugger();
       Q_CHECK_PTR( debugger );
       if ( debugger != 0L ) {
+	       connect(debugger, SIGNAL( debuggerReady()),
+		     this, SLOT(debuggerStarted()));
 	       if (outputview){
 		 connect(debugger,
 			 SIGNAL( showMessage(QString /* msg*/)),
@@ -430,7 +482,7 @@ void KXsldbgPart::createInspector()
 	      if (inspector != 0L){
 		/*process line number and/or file name changed */
 		connect(debugger,
-			SIGNAL( lineNoChanged
+			SIGNAL(lineNoChanged
 				(QString /* fileName */ ,
 				 int /* lineNumber */ ,
 				 bool /* breakpoint */ ) ),
@@ -439,18 +491,6 @@ void KXsldbgPart::createInspector()
 			     ( QString /* fileName */ ,
 			       int /* lineNumber */ ,
 			       bool /* breakpoint */ ) ) );
-		connect(m_editWidget,
-			SIGNAL(addBreakPoint(int /*lineNumber */)),
-			this,
-			SLOT(addBreakPoint(int /* lineNumber */)));
-		connect(m_editWidget,
-			SIGNAL(enableBreakPoint(int /*lineNumber */)),
-			this,
-			SLOT(enableBreakPoint(int /* lineNumber */)));
-		connect(m_editWidget,
-			SIGNAL(deleteBreakPoint(int /*lineNumber */)),
-			this,
-			SLOT(deleteBreakPoint(int /* lineNumber */)));
 		connect(debugger,
 			SIGNAL(breakpointItem(QString /* fileName*/,
 					      int /* lineNumber */,
@@ -539,17 +579,16 @@ KXsldbgPart::outputCmd_activated()
 void KXsldbgPart::refreshCmd_activated()
 {
 
-  if (currentFileName.length() > 0 ){
-
-    QXsldbgDoc *docPtr = docDictionary[currentFileName];
-    if (docPtr != 0L){
-      docPtr->load(currentFileName);
-      m_editWidget->setDocument(docPtr);
-      m_editWidget->repaintAll();
-      /* Reload breakpoints from xsldbg */
-      if ( checkDebugger() ){
+  if ( !currentFileName.isEmpty() ){
+    QDictIterator<QXsldbgDoc> it(docDictionary);
+    QXsldbgDoc *docPtr;
+    while (it.current()){
+      docPtr = it.current();
+      docPtr->refresh();
+     ++it;
+    }
+    if ( checkDebugger() ){
 	debugger->fakeInput("showbreak", TRUE);  // noTr
-      }
     }
   }
 }
@@ -607,47 +646,92 @@ KXsldbgPart::lineNoChanged(QString fileName, int lineNumber, bool breakpoint)
     return;
   }
 
-  if ( lineNumber > 0 )
-    lineNumber--;           /* Take into account the actual cursor position */
+  openURL(fileName);
 
-  if ( currentFileName != fileName){
-    QXsldbgDoc *docPtr = docDictionary[fileName];
-    if (docPtr == 0L){
-      docPtr = new QXsldbgDoc();
-      if (docPtr != 0L){
-	connect( docPtr, SIGNAL(docChanged()),
-		m_editWidget, SLOT(docChanged()));
-	docPtr->load(fileName);
-      docDictionary.insert(fileName, docPtr);
-      m_editWidget->setDocument(docPtr);
-      currentFileName = fileName;
-      }
-    }else{
-      m_editWidget->setDocument(docPtr);
-      currentFileName = fileName;
-    }
-  }
-  /* Did we stop at a breakpoint if so move the marker */
-  if (breakpoint) {
-    m_editWidget->setMarkerPosition(lineNumber, 0);
-    QByteArray params;
-    QDataStream stream(params, IO_WriteOnly);
-    stream << currentFileName << lineNumber;
-    emitDCOPSignal("debuggerPositionChanged(QString,int)", params);
+ /* Did we stop at a breakpoint if so move the marker */
+  if (breakpoint && currentDoc) {
+      currentDoc->selectBreakPoint(lineNumber);
+      QByteArray params;
+      QDataStream stream(params, IO_WriteOnly);
+      stream << currentFileName << lineNumber;
+      emitDCOPSignal("debuggerPositionChanged(QString,int)", params);
   }
 
   /* Move cursor and update status bar */
-  m_editWidget->setCursorPosition( lineNumber, 0 );
+  if (currentDoc && currentDoc->kateView()){
+      KTextEditor::ViewCursorInterface *cursorIf = KTextEditor::viewCursorInterface(currentDoc->kateView());   
+      if (cursorIf){
+	  cursorIf->setCursorPositionReal(lineNumber - 1, 0);
+	  currentLineNo = lineNumber;
+      }
+  }
 }
 
-void KXsldbgPart::editWidget_cursorPositionChanged( int lineNumber, int columnNumber)
+void KXsldbgPart::cursorPositionChanged()
 {
-    currentLineNo = lineNumber + 1;
-    currentColumnNo = columnNumber;
-    QByteArray params;
-    QDataStream stream(params, IO_WriteOnly);
-    stream << currentFileName << lineNumber << columnNumber;
-    emitDCOPSignal("editorPositionChanged(QString,int,int)", params);
+    if (currentDoc && currentDoc->kateView()){  
+	KTextEditor::ViewCursorInterface *viewCurIf = KTextEditor::viewCursorInterface(currentDoc->kateView());   
+	if (viewCurIf){
+	    viewCurIf->cursorPosition(&currentLineNo, &currentColumnNo); 
+	    currentLineNo++;
+	    currentColumnNo++;
+	    QByteArray params;
+	    QDataStream stream(params, IO_WriteOnly);
+	    stream << currentFileName << currentLineNo << currentColumnNo;
+	    emitDCOPSignal("editorPositionChanged(QString,int,int)", params);
+	}
+    }
+}
+
+void  KXsldbgPart::docChanged()
+{
+    if (!currentDoc || currentDoc->kateDoc() || currentDoc->kateView())
+	return;
+}
+
+void  KXsldbgPart::debuggerStarted()
+{
+    if (configWidget != 0L){
+	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+	if (args){
+	    int i=0, result=1, noFilesFound = 0;
+	    QString expandedName;      /* contains file name with path expansion if any */
+
+	    for (i = 0; i < args->count(); i++) {
+		if (!result)
+		    break;
+
+		if (args->arg(i)[0] != '-') {
+		    expandedName = QString::fromUtf8((const char*)filesExpandName((const xmlChar*)args->arg(i)));
+		    if (expandedName.isEmpty()) {
+			result = 0;
+			break;
+		    }
+		    switch (noFilesFound) {
+			case 0:
+			    configWidget->slotSourceFile(expandedName);
+			    noFilesFound++;
+			    break;
+			case 1:
+			    configWidget->slotDataFile(expandedName);
+			    noFilesFound++;
+			    break;
+			case 2:
+			    configWidget->slotOutputFile(expandedName);
+			    noFilesFound++;
+			    break;
+
+			default:
+			    xsldbgGenericErrorFunc(i18n("Error: Too many file names supplied via command line.\n"));
+			    result = 0;
+		    }
+		    continue;
+		}
+	    }  	
+	    configWidget->refresh();
+	    configWidget->show();
+	} 
+    }
 }
 
 void  KXsldbgPart::addBreakPoint(int lineNumber)
@@ -702,7 +786,7 @@ void KXsldbgPart::slotGotoXPath()
 void KXsldbgPart::slotProcResolveItem(QString URI)
 {
   if (!URI.isEmpty()){
-    QMessageBox::information(m_editWidget, i18n("SystemID or PublicID Resolution Result"),
+    QMessageBox::information(mainView, i18n("SystemID or PublicID Resolution Result"),
         i18n("SystemID or PublicID has been resolved to\n.%1").arg(URI),
 	QMessageBox::Ok);
   }
@@ -716,41 +800,30 @@ void  KXsldbgPart::breakpointItem(QString fileName, int lineNumber ,
   if (fileName == 0L){
     /* Go through all documents and remove all breakpoints */
     QDictIterator<QXsldbgDoc> it(docDictionary);
-    QXsldbgTextLine *item;
     QXsldbgDoc *docPtr;
+    KTextEditor::MarkInterface *markIf = 0L;
     while (it.current()){
       docPtr = it.current();
-      for (int index = 0; index < docPtr->lineCount(); index++){
-	item = docPtr->getText(index);
-	if (item != 0L)
-	  item->deleteBreakPoint();
-      }
-      ++it;
+      markIf = KTextEditor::markInterface(docPtr->kateDoc());   
+      if (markIf)
+	   markIf->clearMarks();
+     ++it;
     }
   }else{
-    QXsldbgDoc *docPtr = docDictionary[fileName];
-    QXsldbgTextLine *item;
-    /* Load the file if need */
-    if (docPtr == 0L){
-      docPtr = new QXsldbgDoc();
-      if (docPtr != 0L){
-	connect( docPtr, SIGNAL(docChanged()),
-	        m_editWidget, SLOT(docChanged()));
-	docPtr->load(fileName);
-	docDictionary.insert(fileName, docPtr);
-      }
+/*
+    if (!fileName.contains("://")){
+	// relative path ? must handle this special case
+	KURL url;
+	url.setFileName(fileName);
+	fetchURL(url);
+    }else{
+	fetchURL(fileName);
     }
-    if (docPtr != 0L){
-      item = docPtr->getText(lineNumber);
-      if (item != 0L)
-	item->enableBreakPoint(enabled);
-    }
-  }
-
-  /* This causes a fair amount of flicker for a large amount
-     of breakpoints */
-  if (m_editWidget != 0L){
-    m_editWidget->repaintAll();
+*/
+    fetchURL(fileName);
+    QXsldbgDoc *docPtr = docDictionary[fileName] ;
+   if (docPtr)
+	docPtr->enableBreakPoint(--lineNumber, enabled);
   }
 }
 
