@@ -529,10 +529,10 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                     templateNode =
                         findTemplateNode(styleCtxt->style, &arg[offset]);
                     if (!templateNode) {
-                        xsldbgGenericErrorFunc(i18n("Error: The XSLT template named \"%1\" was not found.\n").arg((char*)&arg[offset]));
+                        xsldbgGenericErrorFunc(i18n("Error: The XSLT template named \"%1\" was not found.\n").arg(xsldbgText(&arg[offset])));
                         return result;
                     } else {
-                        xsldbgGenericErrorFunc(i18n(" template: \"%1\"\n").arg((char*)&arg[offset]));
+                        xsldbgGenericErrorFunc(i18n(" template: \"%1\"\n").arg(xsldbgText(&arg[offset])));
                         ctxt->node = templateNode;
                         result = 1;
                         return result;
@@ -603,9 +603,9 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
                             }
                             result = 1;
                         } else
-                            xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is a Node Set with %n child.", "Warning: XPath %1 is a Node Set with %n children.", list->nodesetval->nodeNr).arg((char*)arg) + QString("\n"));
+                            xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is a Node Set with %n child.", "Warning: XPath %1 is a Node Set with %n children.", list->nodesetval->nodeNr).arg(xsldbgText(arg)) + QString("\n"));
                     } else {
-                        xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is an empty Node Set.\n").arg((char*)arg));
+                        xsldbgGenericErrorFunc(i18n("Warning: XPath %1 is an empty Node Set.\n").arg(xsldbgText(arg)));
                     }
                     break;
 
@@ -614,7 +614,7 @@ xslDbgCd(xsltTransformContextPtr styleCtxt, xmlShellCtxtPtr ctxt,
             }
             xmlXPathFreeObject(list);
         } else {
-            xsldbgGenericErrorFunc(i18n("Error: XPath %1 was not found.\n").arg((char*)arg));
+            xsldbgGenericErrorFunc(i18n("Error: XPath %1 was not found.\n").arg(xsldbgText(arg)));
         }
         ctxt->pctxt->node = NULL;
     }
@@ -668,12 +668,12 @@ xslDbgPrintCallStack(const xmlChar * arg)
 			    if (rootNameTemp && rootModeTemp){
 			      if (rootCopy->match)
 			        /* display information about the current XSLT template */
-                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg((char*)rootCopy->match).arg((char*)rootModeTemp));
+                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg(xsldbgText(rootCopy->match)).arg(xsldbgText(rootModeTemp)));
 			      else
 			        /* display information about the current XSLT template */
-                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg((char*)rootNameTemp).arg((char*)rootModeTemp));
+                                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth).arg(xsldbgText(rootNameTemp)).arg(xsldbgText(rootModeTemp)));
 			      /* display where we are in the source/document file */	
-			      xsldbgGenericErrorFunc(i18n(" in file %1 at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
+			      xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
 			    }else{
 			      xsldbgGenericErrorFunc(i18n("Error: Out of memory.\n"));
 			      result = 0;
@@ -690,7 +690,7 @@ xslDbgPrintCallStack(const xmlChar * arg)
 			    /* display information about the current XSLT template */
                             xsldbgGenericErrorFunc(i18n("#%1 template: \"LIBXSLT_DEFAULT\" mode: \"\"").arg(depth));
 			    /* display where we are in the source/document file */	
-                            xsldbgGenericErrorFunc(i18n(" in file %1 at line %2\n").arg((char*)curUrl).arg(curLine));
+                            xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(curUrl)).arg(curLine));
                         }
                         if (curUrl)
                             xmlFree(curUrl);
@@ -702,10 +702,10 @@ xslDbgPrintCallStack(const xmlChar * arg)
 					 callPointItem->info->modeName);
 		    if (nameTemp && modeTemp){
 		      /* display information about the current XSLT template */
-		      xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth - 1).arg((char*)nameTemp).arg((char*)modeTemp));
+		      xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\" mode: \"%3\"").arg(depth - 1).arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
 		      if (callPointItem->info->url)
 			/* display where we are in the source/document file */	
-                        xsldbgGenericErrorFunc(i18n(" in file %1 at line %2\n").arg((char*)callPointItem->info->url).arg(callPointItem->lineNo));
+                        xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(callPointItem->info->url)).arg(callPointItem->lineNo));
 		      else
                         xsldbgGenericErrorFunc("\n");
 		    }else{
@@ -754,11 +754,11 @@ xslDbgPrintCallStack(const xmlChar * arg)
             callPointItem = callStackGet(templateDepth + 1);
             if (callPointItem && callPointItem->info) {
 		/* display information about the current XSLT template */
-                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\"").arg(templateDepth).arg((char*)callPointItem->info->templateName));
+                xsldbgGenericErrorFunc(i18n("#%1 template: \"%2\"").arg(templateDepth).arg(xsldbgText(callPointItem->info->templateName)));
                 /* should alays be present but .. */
                 if (callPointItem->info->url)
 		    /* display where we are in the source/document file */	
-                    xsldbgGenericErrorFunc(i18n(" in file %1 at line %2\n").arg((char*)callPointItem->info->url).arg(callPointItem->lineNo));
+                    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2\n").arg(xsldbgUrl(callPointItem->info->url)).arg(callPointItem->lineNo));
                 else
                     xsldbgGenericErrorFunc("\n");
             } else {
@@ -1100,18 +1100,18 @@ debugXSLBreak(xmlNodePtr templ, xmlNodePtr node, xsltTemplatePtr root,
 	    in the process of completing the next command */
 	  if (terminalIO == NULL) {
             if (root->match)
-                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg((char*)root->match).arg((char*)modeTemp));
+                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp)));
             else
-                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg((char*)nameTemp).arg((char*)modeTemp));
+                xsldbgGenericErrorFunc(i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp)));
 	  } else {
             if ((xslDebugStatus == DEBUG_TRACE) ||
                 (xslDebugStatus == DEBUG_WALK)) {
 		QString message;
                 if (root->match)
-		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg((char*)root->match).arg((char*)modeTemp);
+		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(root->match)).arg(xsldbgText(modeTemp));
                 else
-		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg((char*)nameTemp).arg((char*)modeTemp);
-		fprintf(terminalIO, "%s", message.utf8().data());
+		  message = i18n("\nReached template: \"%1\" mode: \"%2\"\n").arg(xsldbgText(nameTemp)).arg(xsldbgText(modeTemp));
+		fprintf(terminalIO, "%s", message.local8Bit().data());
             }
 	  }
 	}
@@ -1267,9 +1267,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 breakUri = ctxt->node->doc->URL;
 
             if (xmlGetLineNo(ctxt->node) != -1)
-		messageTxt = i18n("Breakpoint for file %1 at line %2.\n").arg(xsldbgUrl(breakUri)).arg(xmlGetLineNo(ctxt->node));
+		messageTxt = i18n("Breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(breakUri)).arg(xmlGetLineNo(ctxt->node));
             else
-                messageTxt = i18n("Breakpoint at text node in file %1.\n").arg(xsldbgUrl(breakUri));
+                messageTxt = i18n("Breakpoint at text node in file \"%1\".\n").arg(xsldbgUrl(breakUri));
             if (baseUri != NULL) {
                 xmlFree(baseUri);
                 baseUri = NULL;
@@ -1525,7 +1525,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 xslDbgPrintCallStack(NULL);
                 if (getThreadStatus() != XSLDBG_MSG_THREAD_RUN) {
                     if (!xmlShellPwd(ctxt, (char *) dir, ctxt->node, NULL)){
-                        xsldbgGenericErrorFunc((char *)dir);
+                        xsldbgGenericErrorFunc((const char*)dir);
                         xsldbgGenericErrorFunc("\n");
 		    }
                 }
@@ -1681,7 +1681,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		  if(tempBaseName){
 		    xsldbgGenericErrorFunc("\n");
 		    xsldbgGenericErrorFunc((char*)dir);
-		    xsldbgGenericErrorFunc(i18n(" in file %1 at line %2").arg((char*)tempBaseName).arg(xmlGetLineNo(ctxt->node)));
+		    xsldbgGenericErrorFunc(i18n(" in file \"%1\" at line %2").arg(xsldbgUrl(tempBaseName)).arg(xmlGetLineNo(ctxt->node)));
 		    xmlFree(tempBaseName);
 		    cmdResult = 1;
 		  }
@@ -1770,6 +1770,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 
                         optionsSetStringOption(OPTIONS_SOURCE_FILE_NAME,
                                                expandedName);
+			notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
                         loadedFiles = 1;
                         xmlFree(expandedName);
                         cmdResult = 1;
@@ -1809,6 +1810,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 
                         optionsSetStringOption(OPTIONS_DATA_FILE_NAME,
                                                expandedName);
+			notifyXsldbgApp(XSLDBG_MSG_FILE_CHANGED, 0L);
                         loadedFiles = 1;
                         xmlFree(expandedName);
                         cmdResult = 1;
@@ -1966,7 +1968,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		  /* gdb does to say anything after redirecting its 
 		     output */
 		  if (optionsGetIntOption(OPTIONS_GDB) < 2)
-                    xsldbgGenericErrorFunc(i18n("Opening terminal %1.\n").arg((char*)arg));
+                    xsldbgGenericErrorFunc(i18n("Opening terminal %1.\n").arg(xsldbgText(arg)));
                     cmdResult = 1;
                 } else
                     cmdResult = 0;
@@ -2050,7 +2052,7 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
                 break;
 
             default:
-                xsldbgGenericErrorFunc(i18n("Error: Unknown command %1. Try help.\n").arg((char*)command));
+                xsldbgGenericErrorFunc(i18n("Error: Unknown command %1. Try help.\n").arg(xsldbgText(command)));
                 cmdResult = 0;
         }
 
@@ -2061,9 +2063,9 @@ shellPrompt(xmlNodePtr source, xmlNodePtr doc, xmlChar * filename,
 		ctxt->node->doc && ctxt->node->doc->URL) {
 
                 if (xmlGetLineNo(ctxt->node) != -1)
-                    xsldbgGenericErrorFunc(i18n("Breakpoint for file %1 at line %2.\n").arg(xsldbgUrl(ctxt->node->doc->URL)).arg(xmlGetLineNo(ctxt->node)));
+                    xsldbgGenericErrorFunc(i18n("Breakpoint for file \"%1\" at line %2.\n").arg(xsldbgUrl(ctxt->node->doc->URL)).arg(xmlGetLineNo(ctxt->node)));
                 else
-                    xsldbgGenericErrorFunc(i18n("Breakpoint at text node in file %1.\n").arg(xsldbgUrl(ctxt->node->doc->URL)));
+                    xsldbgGenericErrorFunc(i18n("Breakpoint at text node in file \"%1\".\n").arg(xsldbgUrl(ctxt->node->doc->URL)));
             }
         }
 
