@@ -404,7 +404,7 @@ searchSave(const xmlChar * fileName)
     if (xmlSaveFormatFile((char *) searchInput, searchDataBase, 1) != -1){
         result = 1;
     }else{
-        xsldbgGenericErrorFunc(i18n("Error: Unable to write search Database to file %1. Try setting the \"searchresultspath\" option to a writable path.\n").arg((char*)searchInput));
+        xsldbgGenericErrorFunc(i18n("Error: Unable to write search Database to file %1. Try setting the \"searchresultspath\" option to a writable path.\n").arg(xsldbgText(searchInput)));
     }
 
     if (searchInput)
@@ -479,7 +479,7 @@ searchQuery(const xmlChar * tempFile, const xmlChar * outputFile,
             result = filesMoreFile(searchOutput, NULL);
         }
 
-        xsldbgGenericErrorFunc(i18n("Information: Transformed %1 using %2 and saved to %3.\n").arg((char*)searchInput).arg((char*)searchXSL).arg((char*)searchOutput));
+        xsldbgGenericErrorFunc(i18n("Information: Transformed %1 using %2 and saved to %3.\n").arg(xsldbgText(searchInput)).arg(xsldbgText(searchXSL)).arg(xsldbgText(searchOutput)));
     } else {
         xsldbgGenericErrorFunc(i18n("Error: Invalid arguments to command %1.\n").arg("search"));
     }
@@ -720,7 +720,7 @@ findTemplateNode(xsltStylesheetPtr style, const xmlChar * name)
     }
 
     if (!result)
-        xsldbgGenericErrorFunc(i18n("Error: XSLT template named \"%1\" was not found.\n").arg((char*)name));
+        xsldbgGenericErrorFunc(i18n("Error: XSLT template named \"%1\" was not found.\n").arg(xsldbgText(name)));
     return result;
 }
 
