@@ -1333,7 +1333,7 @@ xsldbgGenericErrorFunc(void *ctx, const char *msg, ...)
 
 void xsldbgGenericErrorFunc(QString const &text)
 {
-    xsldbgGenericErrorFunc(0, text.utf8());
+    xsldbgGenericErrorFunc(0, "%s", text.utf8().data());
 }
 
 
