@@ -23,6 +23,11 @@
 #include <kdialogbase.h>
 #include <knewstuff/provider.h>
 
+#if !KDE_IS_VERSION(3,3,2)
+# undef KDE_EXPORT
+# define KDE_EXPORT
+#endif
+
 namespace KIO
 {
   class Job;
