@@ -33,6 +33,7 @@
 #include <qrect.h>
 #include <qspinbox.h>
 #include <qstring.h>
+#include <qtabwidget.h>
 #include <qvaluevector.h>
 
 //own includes
@@ -42,8 +43,6 @@
 #include "tag.h"
 
 #include "quantacommon.h"
-#include "quanta.h"
-#include "resource.h"
 #include "tableitem.h"
 #include "tableeditor.h"
 
@@ -1134,7 +1133,7 @@ void TableEditor::slotEditChildTable()
       }
       childTableNode->next->tag->endPos(table.eLine, table.eCol);
       TableEditor editor;
-      editor.setCaption(i18n("Child Table Editor"));
+      editor.setCaption("Child Table Editor");
       editor.setBaseURL(m_baseURL);
       editor.setTableArea(table.bLine, table.bCol, table.eLine, table.eCol, localParser);
       if (editor.exec()) {
