@@ -27,6 +27,7 @@ namespace DOM
 }
 class Node;
 class NodeModifsSet;
+class NodeSelectionInd;
 class Document;
 struct DTDStruct;
 
@@ -83,6 +84,11 @@ public:
 	 */
 	static Node* getPrevNodeNE(Node *node, Node *endNode = 0L);
 
+    
+    static Node* DTDGetNonInlineCommonParent(Node* startNode, Node* endNode, 
+                                             QValueList<int>& commonParentStartChildLocation, 
+                                             QValueList<int>& commonParentEndChildLocation, Node* nodeSubtree);
+
 	/**
 	 * This function returns the next DOM::Node after node : the first child of
 	 * DOM::Node if available, else its next sibling if available, else the next
@@ -106,7 +112,7 @@ public:
 	 * @return Returns the previous DOM::Node of node.
 	 */
 	static DOM::Node getPrevDomNode(DOM::Node node, DOM::Node endNode = DOM::Node());
-
+    
 
 	/** ----------------------- NODE INDENTATION STUFF -------------------------------------*/
 
@@ -116,8 +122,17 @@ public:
 	 * @param node Apply nice indentation to this Node.
 	 * @param nbOfSpaces Specifies the number of spaces the minimal indentation must be.
 	 * @param nbOfTabs Specifies the number of tabs the minimal indentation must be.
+     * @param modifs The changes made are logged into modifs.
+     * @param inlineNodeIndentation 
+     * If true: 
+     *      <body>Text</body> 
+     * else: 
+     *      <body>
+     *          Text
+     *      </body>
 	 */
-	static void applyIndentation(Node *node, int nbOfSpaces, int nbOfTabs);
+	static void applyIndentation(Node *node, int nbOfSpaces, int nbOfTabs, NodeModifsSet *modifs, 
+                                 bool inlineNodeIndentation = false);
 
 	/**
 	 * Create/Delete the necessary Empty Nodes between n1 and n2 so that a nice indentation can be
@@ -128,8 +143,9 @@ public:
 	 * n1 should not have non empty childs.
 	 * @param n1 The start node.
 	 * @param n2 The end node.
+         * @param modifs The changes made are logged into modifs.
 	 */
-	static void fitIndentationNodes(Node *n1, Node *n2);
+	static void fitIndentationNodes(Node *n1, Node *n2, NodeModifsSet *modifs);
 
 	/**
 	 * Fits the Nodes positions after a change in the Node tree.
@@ -191,7 +207,14 @@ public:
 	static Node* createNode(const QString &nodeName, const QString &tagString, int nodeType,
 		Document *doc);
 
-	/**
+    /**
+     * Restore a Node that has been pasted, i.e., his doc and dtd pointers.
+     * @param node The Node to be restored.
+     * @param doc The document the Node will belong to.
+     */
+    static void restorePastedNode(Node* node, Document* doc);
+    
+    /**
 	 * Create a !doctype Node with all the necessary attributes. It has a child and a closing Node.
 	 * @param doc It needs the document where the !doctype node will be inserted in order to
 	 * build the right attributes.
@@ -329,9 +352,19 @@ public:
 	 * @return Returns a pointer to the node inserted.
 	 */
 	static Node* insertNodeSubtree(Node *node, Node* parentNode, Node* nextSibling,
-		Node* nextEndSibling, NodeModifsSet *modifs, bool merge = true);
+                                   Node* nextEndSibling, NodeModifsSet *modifs, bool merge = true);
 
 	/**
+     * Split the Nodes as necessary, then check that the subtree is allowed to be inserted 
+     * and then insert the subtree. 
+     * @param node The root node of the Node subtree to insert.
+     * @param selection contains the cursor Node where the insertion will take place.
+     * @param modifs The changes made are logged into modifs.
+     */
+    static Node* DTDInsertNodeSubtree(Node *node, NodeSelectionInd& selection, 
+                                      Node **cursorNode, int& cursorOffset, NodeModifsSet *modifs);
+	
+    /**
 	 * Create a Node of name nodeName, of type nodeType, (see tag.h) connected to the document doc,
 	 * and nextSibling as Node's next sibling.
 	 * This function does not try to know if the location of the new Node is valid.
@@ -412,7 +445,7 @@ public:
 
 	/**
 	 * Create a copy of Node. It use the Node copy operator and add some kafka-specific flags :
-	 * It set the cleanStrBuilt to false;
+	 * It set the node->tag->cleanStrBuilt and node->tag->indentationDone to false;
 	 * @param node The node to duplicate.
 	 * @return Returns the duplicated Node. I wonder if i should always write so obvious things ;-)
 	 */
@@ -429,18 +462,18 @@ public:
 	 * This mean that the undo/redo system will delete it when necessary so don't reuse it!!!!
 	 * @param node The node to delete.
 	 * @param modifs The changes made are logged into modifs.
-	 * @param deleteChilds If we remove or move up the children. WARNING: it don't check
+	 * @param extractChilds If we extract or move up the children. WARNING: it don't check
 	 * if the children of node are legal childs of the parent of node.
-	 * @param removeClosingTag Delete the closingTag if node isn't single and is Tag::XmlTag.
+	 * @param removeClosingTag Extract the closingTag if node isn't single and is Tag::XmlTag.
 	 * TODO: @param removeEmbeddedTags Specifies if we delete the embedded Nodes e.g.
 	 * <a href="<? boo ?>" > : the PHP block is an embedded block.
 	 * @return Returns the node extracted with its childs
 	 */
-	static Node* extractNode(Node *node, NodeModifsSet *modifs, bool removeChildren = true,
-		bool removeClosingTag = false/**, bool removeEmbeddedTags = false*/);
+	static Node* extractNode(Node *node, NodeModifsSet *modifs, bool extractChildren = true,
+		bool extractClosingTag = false/**, bool removeEmbeddedTags = false*/);
 
 	/**
-	 * It behaves essentially the above function.
+	 * It behaves essentially like the above function.
 	 * Extract and BUT NOT DELETE RIGHT NOW node from the Tree. The undo/redo system will delete it
 	 * when necessary.
 	 * TODO: remove it, and use extractNode instead.
@@ -448,8 +481,50 @@ public:
 	 */
 	static void extractAndDeleteNode(Node *node, NodeModifsSet *modifs, bool deleteChildren = true,
 		bool deleteClosingTag = true, bool mergeAndFormat = true);
+    
+    /**
+     * Extract a node subtree in the tree. WARNING This function will log that the nodes were added.
+     * @param startNode The node from which we start the removal.
+     * @param startOffset The offset of startNode from which we start the removal.
+     * @param endNode The node from which we end the removal.
+     * @param endOffset The offset of endNode from which we end the removal.
+     * @param cursorNode The cursor is inside cursorNode.
+     * @param cursorOffset The offset of the cursor inside cursorNode.
+     * @return Returns a pointer to the node inserted.
+     */
+    static Node* DTDExtractNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset, 
+                                       Node **cursorNode, int &cursorOffset, NodeModifsSet *modifs);
+    
+    /**
+     * Similar to the above function but it operates on the given node tree. See DTDGetNodeSubtree.
+     * @param nodeSubtree The Node tree on which we're going to make the removal.
+     * @return Returns a pointer to the node inserted.
+     */
+    static Node* DTDExtractNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset, 
+                                       Node* nodeSubtree, NodeModifsSet* modifs);
+    
+    static Node* extractNodeSubtreeAux(Node* commonParentStartChild, Node* commonParentEndChild, NodeModifsSet* modifs);
+    
+    /**
+     * It behaves essentially like the above function. Provided for convenience.
+     */
+    static Node* DTDRemoveSelection(NodeSelectionInd& selection, 
+                                    Node **cursorNode, int& cursorOffset, NodeModifsSet *modifs);
 
-	/**
+    /**
+     * Get a node subtree from the tree. It is similar to extractNodeSubtree() 
+     * but it doesn't extract anything. 
+     * It's useful to get a copy of the Node subtree from a selection, for example.
+     * @param startNode The starting Node.
+     * @param startOffset If firstNode is a text, specify at which offset the new start Node will be splitted.
+     * @param endNode The ending Node.
+     * @param endOffset If endNode is a text, specify at which offset the new end Node will be splitted.
+     * @return Returns a pointer to the Node subtree.
+     */
+    static Node* getNodeSubtree(Node *startNode, int startOffset, Node *endNode, int endOffset/*, 
+            NodeModifsSet *modifs*/);
+	
+    /**
 	 * An enumeration of all the possible return states of DTDExtractNode
 	 */
 	enum extractNodeStatus
@@ -498,7 +573,7 @@ public:
 	 * @param merge Specifies if it should try to merge the Node at its new location.
 	 */
 	static void moveNode(Node *nodeToMove, Node *newParent, Node *newNextSibling,
-		NodeModifsSet *modifs, bool merge = true);
+                         NodeModifsSet *modifs, bool merge = true, bool moveClosingNode = false);
 
 	/**
 	 * Split a Text Node at offset offset. If offset or n is invalid, nothing is done.
@@ -508,11 +583,18 @@ public:
 	 * @return Returns if the node was splitted.
 	 */
 	static bool splitNode(Node *n, int offset, NodeModifsSet *modifs);
+    
+    static void splitStartNodeSubtree(Node* startNode, Node* commonParent, 
+                                      QValueList<int>& commonParentStartChildLocation, NodeModifsSet* modifs);
+    static void splitEndNodeSubtree(Node* endNode, Node* commonParent, 
+                                    QValueList<int>& commonParentStartChildLocation, 
+                                    QValueList<int>& commonParentEndChildLocation, 
+                                    bool subTree, NodeModifsSet* modifs);
 
 	/**
 	 * If n and n2 are both Text or Empty Nodes, merge them into one.
 	 * WARNING if merging occurs, n2 is deleted.
-	 * @param modifs The changes made are logged into modifs
+	 * @param modifs The changes made are logged into modifs.
 	 * @param mergeTextOnly Specify if we should only merge text Nodes, not empty ones.
 	 * @return Returns true if the Nodes were merged, else false.
 	 */
@@ -555,14 +637,20 @@ public:
 	 * Set the tag string of node, and update the start/end position of the Node.
 	 * @param node The node which get the new tag string.
 	 * @param newTagString The new tag String :-)
+         * @param modifs The changes made are logged into modifs.
 	 */
-	static void setTagString(Node *node, const QString &newTagString);
+	static void setTagString(Node *node, const QString &newTagString, NodeModifsSet* modifs);
 
 	/**
 	 * This function behaves essentially like the above function except that all the others Nodes' position
 	 * are updated too.
 	 */
-	static void setTagStringAndFitsNodes(Node *node, const QString &newTagString);
+	static void setTagStringAndFitsNodes(Node *node, const QString &newTagString, NodeModifsSet* modifs);
+        
+    /**
+     * This function behaves exactly like Node::editAttribute except that the change is logged inside a NodeModifsSet.
+     */
+    static void editNodeAttribute(Node* node, const QString& name, const QString& value, NodeModifsSet* modifs);
 
 	/**
 	 * Gets the location of a Node in a pointer-independant suit of ints e.g. 1,3,5 means
@@ -585,6 +673,12 @@ public:
 	 */
 	static Node* getNodeFromLocation(QValueList<int> loc);
 
+    /**
+     * Similar to the above function but instead of using baseNode it uses the passes Node tree.
+     * @param nodeTree Node tree where to get the location.
+     */
+    static Node* getNodeFromLocation(QValueList<int> loc, Node* nodeTree);
+
 	/**
 	 * It behaves essentially like the above function except that it operate on DOM::Nodes.
 	 * @rootNode It needs the root Node of the DOM::Node Tree i.e. the document() Node.
@@ -599,6 +693,8 @@ public:
 	 */
 	static Node* getNodeFromSubLocation(QValueList<int> loc, int locOffset);
 
+    static Node* getNodeFromSubLocation(QValueList<int> loc, int locOffset, Node* nodeTree);
+
 	/**
 	 * A enumeration for kafkaCommon::compareNodePosition().
 	 */
@@ -811,8 +907,6 @@ public:
 	 * @param indent The number of little dots per parent relationship.
 	 */
 	static void coutTree(Node *node, int indent);
-
-
 };
 
 #endif
