@@ -24,19 +24,22 @@
 #include <qmainwindow.h>
 #include <qtimer.h>
 #include <qtooltip.h>
+#include <qpopupmenu.h> 
 
-#include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <khtmlview.h>
 #include <kmessagebox.h>
 #include <ktrader.h>
 #include <klibloader.h>
 #include <kparts/factory.h>
+#include <dom/dom_node.h>
 #include <dom/dom_text.h>
 #include <dom/dom_exception.h>
 #include <dom/dom_string.h>
 #include <dom/dom2_range.h>
 #include <khtml_events.h>
+//#include <khtml_part.h>
 
 #include "kafkacommon.h"
 #ifdef HEAVY_DEBUG
@@ -44,12 +47,18 @@
 #include <qdialog.h>
 #endif
 #include "wkafkapart.h"
+#include "undoredo.h"
 #include "nodeproperties.h"
+#include "tagactionset.h"
 #include "document.h"
 #include "resource.h"
+#include "quantacommon.h"
 #include "quanta.h"
 #include "quantaview.h"
 #include "tagattributetree.h"
+#include "tagactionmanager.h"
+#include "tagactionset.h"
+#include "cursors.h"
 
 #include "viewmanager.h"
 
@@ -67,30 +76,37 @@ public:
     	original node X pos like a good text editor :=) */
     bool stuckCursorHorizontalPos;
     int stuckedCursorPosX;
+    
 #ifdef HEAVY_DEBUG
-
     KafkaDOMTreeDialog *domdialog;
 #endif
 };
 
 KafkaWidget::KafkaWidget(QWidget *parent, QWidget *widgetParent, KafkaDocument *part,
                          const char *name)
-        : KHTMLPart(new KafkaHTMLView(this, widgetParent, name), parent, name),
+        : KHTMLPart(new KHTMLView(this, widgetParent, name), parent, name),
         w(part)
 {
+    m_contextPopupMenu = new QPopupMenu();
+    
     d = new KafkaWidgetPrivate();
- 
+
     d->m_cursorOffset = 0;
     d->m_pressOffset = 0;
     d->m_releaseOffset = 0;
     d->stuckCursorHorizontalPos = false;
 
+    m_modifs = 0L;
+
     // With the mix of Leo Savernik's caret Mode and the current editing
     // functions, it will be kind of VERY messy
     setCaretMode(true);
     connect(this, SIGNAL(caretPositionChanged(const DOM::Node &, long)),
             this, SLOT(slotNewCursorPos(const DOM::Node &, long)));
     setCaretDisplayPolicyNonFocused(KHTMLPart::CaretVisible);
+    
+    connect(this, SIGNAL(popupMenu(const QString&, const QPoint&)),
+            this, SLOT(slotContextMenuRequested(const QString&, const QPoint&)));
 
     view()->setMouseTracking(true);
     view()->installEventFilter(this);
@@ -161,7 +177,7 @@ void KafkaWidget::insertText(DOM::Node node, const QString &text, int position)
             node.appendChild(textNode);
             m_currentNode = textNode;
             d->m_cursorOffset = text.length();
-            emit domNodeInserted(textNode, false);
+            emit domNodeInserted(textNode, false, m_modifs);
 #ifdef LIGHT_DEBUG
 
             kdDebug(25001) << "KafkaWidget::insertText() - added text - 1" << endl;
@@ -178,7 +194,7 @@ void KafkaWidget::insertText(DOM::Node node, const QString &text, int position)
         DOM::DOMString textSplitted = textNode.split(position);
         node.setNodeValue(textNode + text + textSplitted);
         d->m_cursorOffset += text.length();
-        emit domNodeModified(node);
+        emit domNodeModified(node, m_modifs);
 #ifdef LIGHT_DEBUG
 
         kdDebug(25001) << "KafkaWidget::insertText() - added text" << endl;
@@ -192,7 +208,7 @@ void KafkaWidget::insertText(DOM::Node node, const QString &text, int position)
         parent.insertBefore(textNode, node);
         m_currentNode = textNode;
         d->m_cursorOffset = text.length();
-        emit domNodeInserted(textNode, false);
+        emit domNodeInserted(textNode, false, m_modifs);
 #ifdef LIGHT_DEBUG
 
         kdDebug(25001) << "KafkaWidget::insertText() - added text - 2" << endl;
@@ -206,7 +222,7 @@ void KafkaWidget::insertText(DOM::Node node, const QString &text, int position)
         parent.insertBefore(textNode, node.nextSibling());
         m_currentNode = textNode;
         d->m_cursorOffset = text.length();
-        emit domNodeInserted(textNode, false);
+        emit domNodeInserted(textNode, false, m_modifs);
 #ifdef LIGHT_DEBUG
 
         kdDebug(25001) << "KafkaWidget::insertText() - added text - 3" << endl;
@@ -222,7 +238,7 @@ void KafkaWidget::insertText(DOM::Node node, const QString &text, int position)
             node.appendChild(textNode);
         m_currentNode = textNode;
         d->m_cursorOffset = text.length();
-        emit domNodeInserted(textNode, false);
+        emit domNodeInserted(textNode, false, m_modifs);
 #ifdef LIGHT_DEBUG
 
         kdDebug(25001) << "KafkaWidget::insertText() - added text - 4" << endl;
@@ -262,8 +278,8 @@ void KafkaWidget::normalize(DOM::Node _node)
             {
                 childNode.setNodeValue(childNode.nodeValue() +
                                        childNode.nextSibling().nodeValue());
-                emit domNodeModified(childNode);
-                emit domNodeIsAboutToBeRemoved(childNode.nextSibling(), true);
+                emit domNodeModified(childNode, m_modifs);
+                emit domNodeIsAboutToBeRemoved(childNode.nextSibling(), true, m_modifs);
                 _node.removeChild(childNode.nextSibling());
             }
         }
@@ -278,7 +294,7 @@ void KafkaWidget::keyReturn(bool specialPressed)
     int focus;
     //	QTag *qTag;
     bool childOfP;
-    kNodeAttrs *props;
+    //kNodeAttrs *props;
 
     if(m_currentNode.isNull())
         return;
@@ -314,8 +330,8 @@ void KafkaWidget::keyReturn(bool specialPressed)
         {
             text = m_currentNode;
             text2 = (static_cast<DOM::Text>(m_currentNode)).splitText(d->m_cursorOffset);
-            emit domNodeModified(m_currentNode);
-            emit domNodeInserted(text2, false);
+            emit domNodeModified(m_currentNode, m_modifs);
+            emit domNodeInserted(text2, false, m_modifs);
         }
 
         if(!specialPressed)
@@ -394,39 +410,39 @@ void KafkaWidget::keyReturn(bool specialPressed)
         else
             w->insertDomNode(brDomNode, m_currentNode.parentNode(),
                              text2);
-        emit domNodeInserted(brDomNode, false);
+        emit domNodeInserted(brDomNode, false, m_modifs);
         if(!text2.isNull())
             m_currentNode = text2;
         else
         {
-          if(!brDomNode.nextSibling().isNull())
-            m_currentNode = brDomNode.nextSibling();
-          if(!brDomNode.nextSibling().isNull() && brDomNode.nextSibling().nextSibling().isNull())
-          {
-            //TEMP before the webcore caret.
-            brDomNode2 = kafkaCommon::createDomNode("br", w->getCurrentDoc()->defaultDTD(),
-              document());
             if(!brDomNode.nextSibling().isNull())
-              w->insertDomNode(brDomNode2, m_currentNode.parentNode(),
-                DOM::Node());
-    
-            emit domNodeInserted(brDomNode2, false);
-            m_currentNode = brDomNode;
-          }
-          
-         }
+                m_currentNode = brDomNode.nextSibling();
+            if(!brDomNode.nextSibling().isNull() && brDomNode.nextSibling().nextSibling().isNull())
+            {
+                //TEMP before the webcore caret.
+                brDomNode2 = kafkaCommon::createDomNode("br", w->getCurrentDoc()->defaultDTD(),
+                                                        document());
+                if(!brDomNode.nextSibling().isNull())
+                    w->insertDomNode(brDomNode2, m_currentNode.parentNode(),
+                                     DOM::Node());
+
+                emit domNodeInserted(brDomNode2, false, m_modifs);
+                m_currentNode = brDomNode;
+            }
+
+        }
         d->m_cursorOffset = 0;
 
     }
     else if( m_currentNode.nodeName().string().lower() == "br")
     {
-      brDomNode = kafkaCommon::createDomNode("br", w->getCurrentDoc()->defaultDTD(),
-        document());
-      w->insertDomNode(brDomNode, m_currentNode.parentNode(),
-        brDomNode.nextSibling());
-      emit domNodeInserted(brDomNode, false);
-      m_currentNode = brDomNode;
-      d->m_cursorOffset = 0;
+        brDomNode = kafkaCommon::createDomNode("br", w->getCurrentDoc()->defaultDTD(),
+                                               document());
+        w->insertDomNode(brDomNode, m_currentNode.parentNode(),
+                         brDomNode.nextSibling());
+        emit domNodeInserted(brDomNode, false, m_modifs);
+        m_currentNode = brDomNode;
+        d->m_cursorOffset = 0;
     }
 
 #ifdef HEAVY_DEBUG
@@ -444,6 +460,7 @@ void KafkaWidget::keyReturn(bool specialPressed)
     << m_currentNode.nodeValue().string() << " : " << d->m_cursorOffset << endl;
 #endif
 
+    QTimer::singleShot(0, this, SLOT(slotDelayedSetCaretPosition()));
 }
 
 bool KafkaWidget::eventFilter(QObject *, QEvent *event)
@@ -470,11 +487,14 @@ bool KafkaWidget::eventFilter(QObject *, QEvent *event)
 
         emit hasFocus(false);
     }
-
+    
     if(event->type() == QEvent::KeyPress)
     {
         QKeyEvent *keyevent = static_cast<QKeyEvent *>(event);
 
+        //Create a new NodeModifsSet where the changes will be logged.
+        m_modifs = new NodeModifsSet();
+
         switch(keyevent->key())
         {
         case Key_Left:
@@ -540,6 +560,8 @@ bool KafkaWidget::eventFilter(QObject *, QEvent *event)
                     w->getAttrs(m_currentNode)->chCurFoc() != kNodeAttrs::no)
             {
                 // @todo check tab settings in Quanta
+                if(hasSelection())
+                    removeSelection();
                 insertText("    ", -1);
                 makeCursorVisible();
             }
@@ -549,16 +571,16 @@ bool KafkaWidget::eventFilter(QObject *, QEvent *event)
         case Key_BackTab:
             break;
         case Key_Return:
+        case Key_Enter:
 #ifdef LIGHT_DEBUG
 
             kdDebug(25001)<< "KafkaWidget::eventFilter() Return" << endl;
 #endif
-
+            if(hasSelection())
+                removeSelection();
             keyReturn(keyevent->state() & ControlButton);
             d->stuckCursorHorizontalPos = false;
             break;
-        case Key_Enter:
-            break;
         case Key_Insert:
             break;
         case Key_Pause:
@@ -621,7 +643,12 @@ bool KafkaWidget::eventFilter(QObject *, QEvent *event)
                           !( keyevent->state() & MetaButton ) ||
                           ( ( (keyevent->state()&ControlButton) | AltButton ) == (ControlButton|AltButton) ) ) &&
                         ( !keyevent->ascii() || keyevent->ascii() >= 32 || keyevent->text() == "\t" ) )
+                {
+                    if(hasSelection())
+                        removeSelection();
+
                     insertText(keyevent->text(), -1);
+                }
                 makeCursorVisible();
 #ifdef HEAVY_DEBUG
                 //w->coutLinkTree(baseNode, 2);
@@ -632,6 +659,10 @@ bool KafkaWidget::eventFilter(QObject *, QEvent *event)
             d->stuckCursorHorizontalPos = false;
             break;
         }
+
+        //Submit the modifs to the undoRedo system.
+        ViewManager::ref()->activeDocument()->docUndoRedo->addNewModifsSet(m_modifs, undoRedo::KafkaModif, 0, qConfig.replaceAccented);
+        m_modifs = 0L;
     }
 
 #ifdef LIGHT_DEBUG
@@ -642,6 +673,15 @@ bool KafkaWidget::eventFilter(QObject *, QEvent *event)
     return forgetEvent;
 }
 
+void KafkaWidget::slotContextMenuRequested(const QString& /*url*/, const QPoint& point)
+{
+    TagActionManager::self()->fillWithTagActions(m_contextPopupMenu, nodeUnderMouse());
+
+    if(m_contextPopupMenu->count() != 0)
+        m_contextPopupMenu->popup(point);
+}
+
+
 #if 0
 void KafkaWidget::keyDeleteNodes(DOM::Node &startNode, long &offset, bool backspace)
 {
@@ -742,6 +782,12 @@ void KafkaWidget::keyDelete()
     DOM::Node childOfCommonParent, childOfCommonParent2, commonParent;
     bool _goingTowardsRootNode, isParent, singleNodeDeleted, nextIsBlock, startNode2IsNotInline;
 
+    if(hasSelection())
+    {
+        removeSelection();
+        return;
+    }
+    
     if(m_currentNode.isNull())
         return;
     attrs = w->getAttrs(m_currentNode);
@@ -764,7 +810,7 @@ void KafkaWidget::keyDelete()
         nodeText.split(d->m_cursorOffset);
         m_currentNode.setNodeValue(nodeText + textSplitted);
         m_currentNode.parentNode().applyChanges();
-        emit domNodeModified(m_currentNode);
+        emit domNodeModified(m_currentNode, m_modifs);
         postprocessCursorPosition();
         return;
     }
@@ -827,11 +873,11 @@ void KafkaWidget::keyDelete()
         }
         //here, there is no node right and left that can have the cursor focus
         _node = m_currentNode.parentNode();
-        emit domNodeIsAboutToBeRemoved(m_currentNode, true);
+        emit domNodeIsAboutToBeRemoved(m_currentNode, true, m_modifs);
         _node.removeChild(m_currentNode);
         m_currentNode = document().createTextNode("");
         _node.appendChild(m_currentNode);
-        emit domNodeInserted(m_currentNode, false);
+        emit domNodeInserted(m_currentNode, false, m_modifs);
         setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
         emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);
     }
@@ -867,7 +913,7 @@ void KafkaWidget::keyDelete()
                 DOM::DOMString nodeText = _nodeNext.nodeValue();
                 DOM::DOMString textSplitted = nodeText.split(1);
                 _nodeNext.setNodeValue(textSplitted);
-                emit domNodeModified(_nodeNext);
+                emit domNodeModified(_nodeNext, m_modifs);
                 postprocessCursorPosition();
                 normalize(_nodeNext.parentNode());
                 break;
@@ -887,7 +933,7 @@ void KafkaWidget::keyDelete()
                     _node = _nodeParent;
                     //d->m_cursorOffset = -2;
                 }
-                emit domNodeIsAboutToBeRemoved(_nodeNext, true);
+                emit domNodeIsAboutToBeRemoved(_nodeNext, true, m_modifs);
                 _nodeParent.removeChild(_nodeNext);
                 singleNodeDeleted = true;
                 _nodeParent.applyChanges();
@@ -938,7 +984,7 @@ void KafkaWidget::keyDelete()
             while(!temp.isNull() && !temp.previousSibling().isNull() &&
                     ((kafkaCommon::isInline(temp) && (temp.previousSibling().isNull() ||
                                                       kafkaCommon::isInline(temp.previousSibling()))) /**||
-                                          				(!isInline(temp) && temp.previousSibling().isNull())*/))
+                                                               				(!isInline(temp) && temp.previousSibling().isNull())*/))
                 temp = temp.previousSibling();
             startNode = temp;
 
@@ -955,14 +1001,14 @@ void KafkaWidget::keyDelete()
             while(!temp.isNull() && !temp.nextSibling().isNull() &&
                     ((kafkaCommon::isInline(temp) && (temp.nextSibling().isNull() ||
                                                       kafkaCommon::isInline(temp.nextSibling())))/** ||
-                                          				(!isInline(temp) && temp.nextSibling().isNull())*/))
+                                                               				(!isInline(temp) && temp.nextSibling().isNull())*/))
                 temp = temp.nextSibling();
             endNode2 = temp;
 
             //3 - Move Nodes.
             if(!startNode2.isNull() && startNode2IsNotInline)
             {
-                emit domNodeIsAboutToBeRemoved(startNode2, true);
+                emit domNodeIsAboutToBeRemoved(startNode2, true, m_modifs);
                 startNode2.parentNode().removeChild(startNode2);
             }
             else if(isParent && !nextIsBlock)
@@ -1026,7 +1072,7 @@ void KafkaWidget::keyDelete()
                         !temp.hasChildNodes())
                 {
                     tempParent = temp.parentNode();
-                    emit domNodeIsAboutToBeRemoved(temp, true);
+                    emit domNodeIsAboutToBeRemoved(temp, true, m_modifs);
                     tempParent.removeChild(temp);
                     temp = tempParent;
                     attrsTmp = w->getAttrs(temp);
@@ -1040,7 +1086,7 @@ void KafkaWidget::keyDelete()
                         !temp.hasChildNodes())
                 {
                     tempParent = temp.parentNode();
-                    emit domNodeIsAboutToBeRemoved(temp, true);
+                    emit domNodeIsAboutToBeRemoved(temp, true, m_modifs);
                     tempParent.removeChild(temp);
                     temp = tempParent;
                     attrsTmp = w->getAttrs(temp);
@@ -1068,7 +1114,7 @@ void KafkaWidget::keyDelete()
                 //d->m_cursorOffset = -2;
             }
             focus = w->getAttrs(_nodeNext)->chCurFoc();
-            emit domNodeIsAboutToBeRemoved(_nodeNext, true);
+            emit domNodeIsAboutToBeRemoved(_nodeNext, true, m_modifs);
             _nodeParent.removeChild(_nodeNext);
             singleNodeDeleted = true;
             _nodeNext = _node;
@@ -1106,7 +1152,7 @@ void KafkaWidget::keyDelete()
             {
                 childPosition = kafkaCommon::childPosition(_node);
                 _node = _nodeParent;
-                emit domNodeIsAboutToBeRemoved(_nodeNext, true);
+                emit domNodeIsAboutToBeRemoved(_nodeNext, true, m_modifs);
                 _nodeParent.removeChild(_nodeNext);
                 normalize(_nodeParent);
             }
@@ -1127,7 +1173,7 @@ void KafkaWidget::keyDelete()
 
     /**m_currentNode = _node;
     setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
-    emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);*/
+    emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset, m_modifs);*/
 #endif
 }
 
@@ -1141,12 +1187,18 @@ void KafkaWidget::keyBackspace()
     bool _goingTowardsRootNode, singleNodeDeleted, isParent, prevIsBlock, endNodeIsNotInline, boolTmp;
     QString text;
 
+    if(hasSelection())
+    {
+        removeSelection();
+        return;
+    }
+    
     if(m_currentNode.isNull())
         return;
 
     attrs = w->getAttrs(m_currentNode);
     if(!attrs)
-      return;
+        return;
     m_currentNodeType = m_currentNode.nodeType();
 
 #ifdef HEAVY_DEBUG
@@ -1168,10 +1220,15 @@ void KafkaWidget::keyBackspace()
         DOM::DOMString nodeText = m_currentNode.nodeValue();
         DOM::DOMString textSplitted = nodeText.split(d->m_cursorOffset);
         nodeText.split(d->m_cursorOffset - 1);
+        
+#ifdef LIGHT_DEBUG
+        kdDebug(25001) << nodeText.string() << textSplitted.string() << endl;
+#endif
+        
         m_currentNode.setNodeValue(nodeText + textSplitted);
         m_currentNode.parentNode().applyChanges();
-        d->m_cursorOffset--;
-        emit domNodeModified(m_currentNode);
+        --(d->m_cursorOffset);
+        emit domNodeModified(m_currentNode, m_modifs);
         postprocessCursorPosition();
         setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
         emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);
@@ -1235,11 +1292,11 @@ void KafkaWidget::keyBackspace()
         }
         //here, there is no node right and left that can have the cursor focus
         _node = m_currentNode.parentNode();
-        emit domNodeIsAboutToBeRemoved(m_currentNode, true);
+        emit domNodeIsAboutToBeRemoved(m_currentNode, true, m_modifs);
         _node.removeChild(m_currentNode);
         m_currentNode = document().createTextNode("");
         _node.appendChild(m_currentNode);
-        emit domNodeInserted(m_currentNode, false);
+        emit domNodeInserted(m_currentNode, false, m_modifs);
         setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
         emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);
 
@@ -1260,6 +1317,17 @@ void KafkaWidget::keyBackspace()
 #endif
 
         attrs = w->getAttrs(_nodePrev);
+        if(!attrs)
+        {
+            kdError(25001) << "NULL kNodeAttrs instance: attrs = w->getAttrs(_nodePrev);" << endl;
+            kafkaCommon::coutDomTree(_nodePrev, 3);
+            return; 
+            // FIXME Understand why this happen.
+//             Test case:
+//             1. Write two words in a new VPL document and make the first one a link;
+//             2. Put the cursor at most right and then press backspace until it crashes
+//             When you get to the link the cursor stays in the same plave and you have press it several times until it crashes.
+        }
 
         //If this Node can't be deleted, we stop here.
         if(!attrs->cbDel())
@@ -1279,8 +1347,12 @@ void KafkaWidget::keyBackspace()
                 nodeText.split((static_cast<DOM::CharacterData>(_nodePrev)).length() - 1);
                 _nodePrev.setNodeValue(nodeText);
                 _nodePrev.parentNode().applyChanges();
+                
+                m_currentNode = _nodePrev;
+                d->m_cursorOffset = (static_cast<DOM::CharacterData>(_nodePrev)).length();
+                                
                 postprocessCursorPosition();
-                emit domNodeModified(_nodePrev);
+                emit domNodeModified(_nodePrev, m_modifs);
                 return;
             }
             else
@@ -1291,7 +1363,7 @@ void KafkaWidget::keyBackspace()
 #endif
 
                 _nodeParent = _nodePrev.parentNode();
-                emit domNodeIsAboutToBeRemoved(_nodePrev, true);
+                emit domNodeIsAboutToBeRemoved(_nodePrev, true, m_modifs);
                 _nodeParent.removeChild(_nodePrev);
                 _nodeParent.applyChanges();
                 _nodePrev = _node;
@@ -1364,7 +1436,7 @@ void KafkaWidget::keyBackspace()
             //3 - Move Nodes.
             if(!endNode.isNull() && endNodeIsNotInline)
             {
-                emit domNodeIsAboutToBeRemoved(endNode, true);
+                emit domNodeIsAboutToBeRemoved(endNode, true, m_modifs);
                 endNode.parentNode().removeChild(endNode);
             }
             else if(isParent && !prevIsBlock)
@@ -1433,11 +1505,11 @@ void KafkaWidget::keyBackspace()
                     }
                     text = temp.nodeValue().string() + startNode2.nodeValue().string();
                     tempParent = temp.parentNode();
-                    emit domNodeIsAboutToBeRemoved(startNode2, true);
+                    emit domNodeIsAboutToBeRemoved(startNode2, true, m_modifs);
                     tempParent.removeChild(startNode2);
 
                     temp.setNodeValue(text);
-                    emit domNodeModified(temp);
+                    emit domNodeModified(temp, m_modifs);
 
                     if(boolTmp)
                         QTimer::singleShot(0, this, SLOT(slotDelayedSetCaretPosition()));
@@ -1454,7 +1526,7 @@ void KafkaWidget::keyBackspace()
                         !temp.hasChildNodes())
                 {
                     tempParent = temp.parentNode();
-                    emit domNodeIsAboutToBeRemoved(temp, true);
+                    emit domNodeIsAboutToBeRemoved(temp, true, m_modifs);
                     tempParent.removeChild(temp);
                     temp = tempParent;
                     attrsTmp = w->getAttrs(temp);
@@ -1468,7 +1540,7 @@ void KafkaWidget::keyBackspace()
                         !temp.hasChildNodes())
                 {
                     tempParent = temp.parentNode();
-                    emit domNodeIsAboutToBeRemoved(temp, true);
+                    emit domNodeIsAboutToBeRemoved(temp, true, m_modifs);
                     tempParent.removeChild(temp);
                     temp = tempParent;
                     attrsTmp = w->getAttrs(temp);
@@ -1489,7 +1561,7 @@ void KafkaWidget::keyBackspace()
 
             _nodeParent = _nodePrev.parentNode();
             focus = w->getAttrs(_nodePrev)->chCurFoc();
-            emit domNodeIsAboutToBeRemoved(_nodePrev, true);
+            emit domNodeIsAboutToBeRemoved(_nodePrev, true, m_modifs);
             _nodeParent.removeChild(_nodePrev);
             //normalize(_nodeParent);
             if(focus == kNodeAttrs::singleNodeAndItself)
@@ -1500,38 +1572,40 @@ void KafkaWidget::keyBackspace()
                 //=> It seems it was removed from it.
                 _nodePrev = _node.previousSibling();
                 if(!_nodePrev.isNull() && _nodePrev.nodeType() == DOM::Node::TEXT_NODE &&
-                  m_currentNodeType == DOM::Node::TEXT_NODE)
+                        m_currentNodeType == DOM::Node::TEXT_NODE)
                 {
                     if(_node == m_currentNode)
                     {
-                      m_currentNode = _nodePrev;
-                      d->m_cursorOffset += (static_cast<DOM::CharacterData>(_nodePrev)).length();
-                      QTimer::singleShot(0, this, SLOT(slotDelayedSetCaretPosition()));
+                        m_currentNode = _nodePrev;
+                        d->m_cursorOffset += (static_cast<DOM::CharacterData>(_nodePrev)).length();
+                        QTimer::singleShot(0, this, SLOT(slotDelayedSetCaretPosition()));
                     }
                     _nodePrev.setNodeValue(_nodePrev.nodeValue() + _node.nodeValue());
-                    emit domNodeModified(_nodePrev);
+                    emit domNodeModified(_nodePrev, m_modifs);
                     //_nodeParent = _nodePrev.parentNode();
-                    emit domNodeIsAboutToBeRemoved(_node, true);
+                    emit domNodeIsAboutToBeRemoved(_node, true, m_modifs);
                     _nodeParent.removeChild(_node);
                 }
                 //dirty workaround when after having deleted a br, there is only one br left
                 //Anyway webcore will override this
-                if(m_currentNode.nodeName().string().lower() == "br" && 
-                  (m_currentNode.previousSibling().isNull() || (m_currentNode.previousSibling().nodeType() ==
-                  DOM::Node::TEXT_NODE && m_currentNode.previousSibling().previousSibling().isNull())) &&
-                  (m_currentNode.nextSibling().isNull() || (m_currentNode.nextSibling().nodeType() ==
-                  DOM::Node::TEXT_NODE && m_currentNode.nextSibling().nextSibling().isNull())))
+                if(m_currentNode.nodeName().string().lower() == "br" &&
+                        (m_currentNode.previousSibling().isNull() || (m_currentNode.previousSibling().nodeType() ==
+                                DOM::Node::TEXT_NODE && m_currentNode.previousSibling().previousSibling().isNull())) &&
+                        (m_currentNode.nextSibling().isNull() || (m_currentNode.nextSibling().nodeType() ==
+                                DOM::Node::TEXT_NODE && m_currentNode.nextSibling().nextSibling().isNull())))
                 {
-                  if(!m_currentNode.previousSibling().isNull())
-                  {
-                    m_currentNode = m_currentNode.previousSibling();
-                    d->m_cursorOffset = 0;
-                  }
-                  else if(!m_currentNode.nextSibling().isNull())
-                  {
-                    m_currentNode = m_currentNode.nextSibling();
-                    d->m_cursorOffset = 0;
-                  }
+                    if(!m_currentNode.previousSibling().isNull())
+                    {
+                        m_currentNode = m_currentNode.previousSibling();
+                        d->m_cursorOffset = 0;
+                        
+                        QTimer::singleShot(0, this, SLOT(slotDelayedSetCaretPosition()));
+                    }
+                    else if(!m_currentNode.nextSibling().isNull())
+                    {
+                        m_currentNode = m_currentNode.nextSibling();
+                        d->m_cursorOffset = 0;
+                    }
                 }
                 break;
             }
@@ -1762,48 +1836,48 @@ void KafkaWidget::postprocessCursorPosition()
     if(attrs->chCurFoc() == kNodeAttrs::textNode &&
             d->m_cursorOffset == 0)
     {
-       /** while(1)
-        {
-            _prevNextNode = _nextNode;
-            _nextNode = kafkaCommon::getPrevDomNode(_nextNode);
-            if(_nextNode.isNull())
-                break;
-            attrs2 = w->getAttrs(_nextNode);
-            if(attrs2->chCurFoc() == kNodeAttrs::textNode &&
-                    (static_cast<DOM::CharacterData>(_nextNode)).length() != 0)
-            {
-                m_currentNode = _nextNode;
-                d->m_cursorOffset = (static_cast<DOM::CharacterData>(_nextNode)).length();
-                setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
-                emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);
-#ifdef LIGHT_DEBUG
+        /** while(1)
+         {
+             _prevNextNode = _nextNode;
+             _nextNode = kafkaCommon::getPrevDomNode(_nextNode);
+             if(_nextNode.isNull())
+                 break;
+             attrs2 = w->getAttrs(_nextNode);
+             if(attrs2->chCurFoc() == kNodeAttrs::textNode &&
+                     (static_cast<DOM::CharacterData>(_nextNode)).length() != 0)
+             {
+                 m_currentNode = _nextNode;
+                 d->m_cursorOffset = (static_cast<DOM::CharacterData>(_nextNode)).length();
+                 setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
+                 emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);
+        #ifdef LIGHT_DEBUG
 
-                kdDebug(25001)<< "KafkaWidget::postprocessCursorPosition()" <<
-                " - new currentNode :" <<
-                m_currentNode.nodeName().string() << endl;
-#endif
+                 kdDebug(25001)<< "KafkaWidget::postprocessCursorPosition()" <<
+                 " - new currentNode :" <<
+                 m_currentNode.nodeName().string() << endl;
+        #endif
 
-                break;
-            }
-            else if(attrs2->chCurFoc() == kNodeAttrs::singleNodeAndItself ||
-                    attrs2->chCurFoc() == kNodeAttrs::inlineNode ||
-                    attrs2->chCurFoc() == kNodeAttrs::blockNode)
-                break;
-            else
-                continue;
-        }*/
+                 break;
+             }
+             else if(attrs2->chCurFoc() == kNodeAttrs::singleNodeAndItself ||
+                     attrs2->chCurFoc() == kNodeAttrs::inlineNode ||
+                     attrs2->chCurFoc() == kNodeAttrs::blockNode)
+                 break;
+             else
+                 continue;
+         }*/
     }
     else if(attrs->chCurFoc() == kNodeAttrs::singleNodeAndItself)
     {
         if(d->m_cursorOffset == 0  && !m_currentNode.isNull() &&
-         (m_currentNode.nodeName().string().lower() != "br" ||
-          (m_currentNode.nodeName().string().lower() == "br" && /**!m_currentNode.nextSibling().isNull() &&
-          m_currentNode.nextSibling().nodeType() == DOM::Node::TEXT_NODE &&
-          m_currentNode.nextSibling().nodeValue().string() == "" &&
-          m_currentNode.nextSibling().nextSibling().isNull() &&*/
-          !m_currentNode.previousSibling().isNull() && 
-          m_currentNode.previousSibling().nodeType() == DOM::Node::TEXT_NODE &&
-          m_currentNode.previousSibling().nodeValue().string() != "")))
+                (m_currentNode.nodeName().string().lower() != "br" ||
+                 (m_currentNode.nodeName().string().lower() == "br" && /**!m_currentNode.nextSibling().isNull() &&
+                            m_currentNode.nextSibling().nodeType() == DOM::Node::TEXT_NODE &&
+                            m_currentNode.nextSibling().nodeValue().string() == "" &&
+                            m_currentNode.nextSibling().nextSibling().isNull() &&*/
+                  !m_currentNode.previousSibling().isNull() &&
+                  m_currentNode.previousSibling().nodeType() == DOM::Node::TEXT_NODE &&
+                  !m_currentNode.previousSibling().nodeValue().string().isEmpty())))
         {
             while(1)
             {
@@ -1819,8 +1893,7 @@ void KafkaWidget::postprocessCursorPosition()
                     m_currentNode = _nextNode;
                     d->m_cursorOffset = (static_cast<DOM::CharacterData>(_nextNode)).length();
                     setCaretPosition(m_currentNode, (long)d->m_cursorOffset);
-                    emit domNodeNewCursorPos(m_currentNode,
-                                             d->m_cursorOffset);
+                    emit domNodeNewCursorPos(m_currentNode, d->m_cursorOffset);
 #ifdef LIGHT_DEBUG
 
                     kdDebug(25001)<< "KafkaWidget::postprocessCursorPosition()" <<
@@ -1884,14 +1957,16 @@ void KafkaWidget::postprocessCursorPosition()
 void KafkaWidget::khtmlMouseMoveEvent(khtml::MouseMoveEvent *event)
 {
     DOM::Node mouseNode = event->innerNode();
-    
+
     if(mouseNode == 0)
-        return;
+    {
+      return;
+    }
     if(mouseNode.nodeType() == DOM::Node::TEXT_NODE)
-        KApplication::setOverrideCursor(Qt::ibeamCursor);
+      view()->setCursor(Qt::ibeamCursor);
     else
-        KApplication::setOverrideCursor(Qt::arrowCursor);
-    
+      view()->setCursor(Qt::arrowCursor);
+
     KHTMLPart::khtmlMouseMoveEvent(event);
 }
 
@@ -2017,7 +2092,7 @@ void KafkaWidget::moveDomNodes(DOM::Node newParent, DOM::Node startNode, DOM::No
         while(!domNode.isNull())
         {
             domNodeNext = domNode.previousSibling();
-            emit domNodeIsAboutToBeMoved(domNode, newParent, refNode);
+            emit domNodeIsAboutToBeMoved(domNode, newParent, refNode, m_modifs);
             //emit domNodeIsAboutToBeRemoved(domNode, true);
             domNode = domNode.parentNode().removeChild(domNode);
             if(!refNode.isNull())
@@ -2038,9 +2113,9 @@ void KafkaWidget::moveDomNodes(DOM::Node newParent, DOM::Node startNode, DOM::No
             domNodeNext = domNode.nextSibling();
             //emit domNodeIsAboutToBeRemoved(domNode, true);
             if(!refNode.isNull())
-                emit domNodeIsAboutToBeMoved(domNode, newParent, refNode.nextSibling());
+                emit domNodeIsAboutToBeMoved(domNode, newParent, refNode.nextSibling(), m_modifs);
             else
-                emit domNodeIsAboutToBeMoved(domNode, newParent, DOM::Node());
+                emit domNodeIsAboutToBeMoved(domNode, newParent, DOM::Node(), m_modifs);
             domNode = domNode.parentNode().removeChild(domNode);
             if(!refNode.isNull())
                 newParent.insertBefore(domNode, refNode.nextSibling());
@@ -2054,4 +2129,35 @@ void KafkaWidget::moveDomNodes(DOM::Node newParent, DOM::Node startNode, DOM::No
     }
 }
 
+void KafkaWidget::removeSelection()
+{
+    Q_ASSERT(hasSelection());
+    
+    NodeSelectionInd selection;
+    selection.fillWithVPLCursorSelection();
+    Node* cursorNode = kafkaCommon::getNodeFromLocation(selection.cursorNode());
+    int cursorOffset = 0;
+    long domNodeCursorOffset = 0;
+        
+    kafkaCommon::DTDRemoveSelection(selection, &cursorNode, cursorOffset, m_modifs);
+    
+    KafkaDocument::ref()->translateNodeIntoKafkaCursorPosition(cursorNode, cursorOffset, m_currentNode, domNodeCursorOffset);
+    d->m_cursorOffset = domNodeCursorOffset;
+    
+    setCurrentNode(m_currentNode, domNodeCursorOffset);
+    
+    QTimer::singleShot(0, this, SLOT(slotDelayedSetCaretPosition()));
+    
+    NodeSelection* cursorPos = new NodeSelection();
+    cursorPos->setCursorNode(cursorNode);
+    cursorPos->setCursorOffset(cursorOffset);
+    
+    ViewManager::ref()->activeDocument()->docUndoRedo->addNewModifsSet(m_modifs, undoRedo::NodeTreeModif, cursorPos);
+    m_modifs = 0;        
+
+    delete cursorPos;
+
+    makeCursorVisible();
+}
+
 #include "kafkahtmlpart.moc"
