@@ -90,11 +90,6 @@
 #define STEP 1
 
 extern GroupElementMapList globalGroupMap;
-uint replaceCharList[] = {192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202,
-         203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 216, 217, 218,
-         219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233,
-         234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 248, 249,
-         250, 251, 252, 253, 254, 255, 336, 337, 368, 369, 0};
 
 Document::Document(KTextEditor::Document *doc,
                    QWidget *parent, const char *name, WFlags f )
@@ -146,11 +141,11 @@ Document::Document(KTextEditor::Document *doc,
   a = m_view->actionCollection()->action("view_border");
   if (a)
     a->setShortcut(Qt::SHIFT + Qt::Key_F9);
-  
+
   a = m_view->actionCollection()->action("view_folding_markers");
   if (a)
     a->setShortcut(Qt::SHIFT + Qt::Key_F11);
-  
+
   KActionMenu *bookmarkAction = dynamic_cast<KActionMenu*>(m_view->actionCollection()->action( "bookmarks" ));
   if (bookmarkAction)
   {
@@ -158,9 +153,17 @@ Document::Document(KTextEditor::Document *doc,
     //kdDebug(24000) << "Bookmarks found!" << endl;
     //bookmarkAction->insert(quantaApp->actionCollection()->action( "file_quit" ));
   }
- 
+
   editIf = dynamic_cast<KTextEditor::EditInterface *>(m_doc);
   editIfExt = dynamic_cast<KTextEditor::EditInterfaceExt *>(m_doc);
+  encodingIf = dynamic_cast<KTextEditor::EncodingInterface*>(m_doc);
+  m_encoding = quantaApp->defaultEncoding();
+  if (encodingIf)
+        m_encoding = encodingIf->encoding();
+  if (m_encoding.isEmpty())
+      m_encoding = "utf8";  //final fallback
+  m_codec = QTextCodec::codecForName(m_encoding);
+
   selectionIf = dynamic_cast<KTextEditor::SelectionInterface *>(m_doc);
   selectionIfExt = dynamic_cast<KTextEditor::SelectionInterfaceExt *>(m_doc);
   configIf = dynamic_cast<KTextEditor::ConfigInterface*>(m_doc);
@@ -213,9 +216,9 @@ Document::Document(KTextEditor::Document *doc,
 Document::~Document()
 {
   parser->clearGroups();
-//  kdDebug(24000) << "Document::~ Document: " << this << endl;
- m_doc->closeURL(false); //TODO: Workaround for a Kate bug. Remove when KDE < 3.2.0 support is dropped.
- delete m_doc;
+  //  kdDebug(24000) << "Document::~ Document: " << this << endl;
+  m_doc->closeURL(false); //TODO: Workaround for a Kate bug. Remove when KDE < 3.2.0 support is dropped.
+  delete m_doc;
 }
 
 void Document::setUntitledUrl(const QString &url)
@@ -371,10 +374,10 @@ void Document::selectText(int x1, int y1, int x2, int y2 )
 
 void Document::replaceSelected(const QString &s)
 {
-  if (selectionIf) 
+  if (selectionIf)
   {
     unsigned int line, col;
-    
+
     viewCursorIf->cursorPositionReal(&line, &col);
     reparseEnabled = false;
     selectionIf->removeSelectedText();
@@ -577,7 +580,6 @@ void Document::createTempFile()
   tempFile->setAutoDelete(true);
   m_tempFileName = QFileInfo(*(tempFile->file())).filePath();
   QString encoding = quantaApp->defaultEncoding();
-  KTextEditor::EncodingInterface* encodingIf = dynamic_cast<KTextEditor::EncodingInterface*>(m_doc);
   if (encodingIf)
         encoding = encodingIf->encoding();
   if (encoding.isEmpty())
@@ -735,6 +737,15 @@ void Document::slotFilterCompletion( KTextEditor::CompletionEntry *completion ,Q
   if (completion->type == "charCompletion")
   {
     *string = completion->userdata;
+    uint line, col;
+    viewCursorIf->cursorPositionReal(&line, &col);
+    QString s2 = editIf->textLine(line).left(col);
+    int pos = s2.findRev('&');
+    if (pos != -1)
+    {
+      s2 = s2.mid(pos + 1);
+      string->remove(s2);
+    }
     string->append(";");
   } else
   if ( completion->type == "attributeValue")
@@ -781,24 +792,43 @@ void Document::slotReplaceChar()
 */
 void Document::slotCharactersInserted(int line, int column, const QString& string)
 {
- uint c = string[0].unicode();
- if (qConfig.replaceAccented && c > 191)
- {
-    uint ch = replaceCharList[0];
-    int i = 0;
-    while (ch != 0)
+  if (qConfig.replaceAccented && encodingIf)
+  {
+    QString encoding = encodingIf->encoding();
+    if (encoding != m_encoding)
     {
-        if (c == ch)
-        {
-           m_replaceLine = line;
-           m_replaceCol = column;
-           m_replaceStr = QString("&#%1;").arg(c);
-           QTimer::singleShot(0, this, SLOT(slotReplaceChar()));
-           return;
-        }
-        ch = replaceCharList[++i];
+      m_encoding = encoding;
+      m_codec = QTextCodec::codecForName(encoding);
     }
- }
+    if (!m_codec->canEncode(string[0]))
+    {
+      m_replaceLine = line;
+      m_replaceCol = column;
+      m_replaceStr = QString("&#%1;").arg(string[0].unicode());
+      QTimer::singleShot(0, this, SLOT(slotReplaceChar()));
+      return;    
+    }
+  }
+
+  
+//  uint c = string[0].unicode();
+//  if (qConfig.replaceAccented && c > 191)
+//  {
+//     uint ch = replaceCharList[0];
+//     int i = 0;
+//     while (ch != 0)
+//     {
+//         if (c == ch)
+//         {
+//            m_replaceLine = line;
+//            m_replaceCol = column;
+//            m_replaceStr = QString("&#%1;").arg(c);
+//            QTimer::singleShot(0, this, SLOT(slotReplaceChar()));
+//            return;
+//         }
+//         ch = replaceCharList[++i];
+//     }
+//  }
  if ( (string == ">") ||
       (string == "<") )
  {
@@ -981,13 +1011,15 @@ bool Document::xmlAutoCompletion(int line, int column, const QString & string)
   if (!handled)
   {
     QString s = editIf->textLine(line).left(column + 1);
-    if (s.endsWith("&"))
+    int pos = s.findRev('&');
+    if (pos != -1)
     {
-        //complete character codes
-        showCodeCompletions( getCharacterCompletions("") );
-        handled = true;
+      //complete character codes
+      s = s.mid(pos + 1);
+      showCodeCompletions(getCharacterCompletions(s));
+      handled = true;
     }
-  }
+  } 
  return handled;
 }
 
@@ -1384,12 +1416,12 @@ QValueList<KTextEditor::CompletionEntry>* Document::getCharacterCompletions(cons
 {
   QValueList<KTextEditor::CompletionEntry> *completions = 0L;
   QMap<QString, KTextEditor::CompletionEntry> completionMap;
-      
+
   //first search for entities defined in the document
   const DTDStruct *dtdDTD = DTDs::ref()->find("dtd");
   if (dtdDTD)
   {
-    StructTreeGroup group;    
+    StructTreeGroup group;
     for (uint j = 0; j < dtdDTD->structTreeGroups.count(); j++)
     {
       group = dtdDTD->structTreeGroups[j];
@@ -1410,10 +1442,10 @@ QValueList<KTextEditor::CompletionEntry>* Document::getCharacterCompletions(cons
       }
     }
   }
-  
+
   if (!completions)
     completions = new QValueList<KTextEditor::CompletionEntry>();
-  
+
   KTextEditor::CompletionEntry completion;
   completion.type = "charCompletion";
   //add the entities from the tag files
@@ -1424,7 +1456,7 @@ QValueList<KTextEditor::CompletionEntry>* Document::getCharacterCompletions(cons
     if (tag->type == "entity")
     {
       QString tagName = tag->name(true);
-      if (tagName.upper().startsWith(startsWith))
+      if (tagName.upper().startsWith(startsWith.upper()) || startsWith.isEmpty())
       {
         completion.text = tagName;
         completion.userdata = tagName;
@@ -1433,7 +1465,7 @@ QValueList<KTextEditor::CompletionEntry>* Document::getCharacterCompletions(cons
       }
     }
   }
-  
+
   QValueList<KTextEditor::CompletionEntry> *completions2 = new QValueList<KTextEditor::CompletionEntry>();
   for (QMap<QString, KTextEditor::CompletionEntry>::ConstIterator it = completionMap.constBegin(); it != completionMap.constEnd(); ++it)
   {
@@ -1453,11 +1485,11 @@ QValueList<KTextEditor::CompletionEntry>* Document::getCharacterCompletions(cons
     completion.text = s + " : " + completion.text.left(begin -2) + " - " + completion.text.mid(begin + length + 1);
     if (s.startsWith(startsWith))
     {
-      completion.userdata = startsWith + "|" + s.mid(startsWith.length());
+      completion.userdata = s.mid(startsWith.length());
       completions->append( completion );
     }
   }
-    
+
   return completions;
 }
 
@@ -1614,7 +1646,7 @@ bool Document::scriptAutoCompletion(int line, int column, const QString& inserte
  if (s[i] == completionDTD->tagSeparator)
  {
   while (i > 0 && s[i] != completionDTD->tagAutoCompleteAfter)
-    i--;  
+    i--;
   s = s.left(i + 1);
  }
 
@@ -1688,9 +1720,9 @@ bool Document::scriptAutoCompletion(int line, int column, const QString& inserte
      }
    }
  }
- if ( !handled && !argHintVisible && 
-      (completionRequested || 
-       (s[i] == completionDTD->tagAutoCompleteAfter && (insertedString == " " || insertedString[0] == completionDTD->tagAutoCompleteAfter)) || 
+ if ( !handled && !argHintVisible &&
+      (completionRequested ||
+       (s[i] == completionDTD->tagAutoCompleteAfter && (insertedString == " " || insertedString[0] == completionDTD->tagAutoCompleteAfter)) ||
        completionDTD->tagAutoCompleteAfter == '\1' || (!completionDTD->memberAutoCompleteAfter.pattern().isEmpty() && completionDTD->memberAutoCompleteAfter.searchRev(s) != -1))
        )
  {
@@ -1849,7 +1881,7 @@ void Document::codeCompletionRequested()
   completionRequested = true;
   completionInProgress = false;
   argHintVisible = false;
-  hintRequested = false; 
+  hintRequested = false;
   handleCodeCompletion();
   completionRequested = false;
 }
@@ -1911,7 +1943,7 @@ void Document::codeCompletionHintRequested()
 //    int pos = textLine.findRev("(");
 //    int pos2 = textLine.findRev(")");
     //if (pos > pos2 )
-    hintRequested = true; 
+    hintRequested = true;
     scriptAutoCompletion(line, col - 1, "");
   }
   completionRequested = false;
@@ -2056,12 +2088,11 @@ void Document::checkDirtyStatus()
       if (f.open(IO_ReadOnly) && tmpFile.open(IO_ReadOnly))
       {
         QString encoding = quantaApp->defaultEncoding();
-        KTextEditor::EncodingInterface* encodingIf = dynamic_cast<KTextEditor::EncodingInterface*>(m_doc);
         if (encodingIf)
-        encoding = encodingIf->encoding();
+          encoding = encodingIf->encoding();
         if (encoding.isEmpty())
-        encoding = "utf8";  //final fallback
-
+          encoding = "utf8";  //final fallback
+  
         QString content;
         QTextStream stream(&f);
         stream.setCodec(QTextCodec::codecForName(encoding));
@@ -2331,7 +2362,7 @@ QStringList* Document::tagAttributeValues(const QString& dtdName, const QString&
                 u = QExtFileInfo::toRelative(u, base);
                 (*values)[i] = u.path();
               }
-	      values->remove(values->at(0));
+              values->remove(values->at(0));
               values->append("mailto:" + project->email());
             } else
             {
@@ -2467,7 +2498,6 @@ void Document::createBackup(KConfig* config)
      QStringList backedupFilesEntryList = config->readPathListEntry("List of backedup files");
      QStringList autosavedFilesEntryList = config->readPathListEntry("List of autosaved files");
      QString encoding = quantaApp->defaultEncoding();
-     KTextEditor::EncodingInterface* encodingIf = dynamic_cast<KTextEditor::EncodingInterface*>(m_doc);
      if (encodingIf)
          encoding = encodingIf->encoding();
      if (encoding.isEmpty())
@@ -2645,9 +2675,12 @@ void Document::convertCase()
 
 void Document::open(const KURL &url, const QString &encoding)
 {
-    KTextEditor::EncodingInterface* encodingIf = dynamic_cast<KTextEditor::EncodingInterface*>(m_doc);
     if (encodingIf)
+    {
        encodingIf->setEncoding(encoding);
+       m_encoding = encoding;
+       m_codec = QTextCodec::codecForName(m_encoding);
+    }
     connect(m_doc, SIGNAL(completed()), this, SLOT(slotOpeningCompleted()));
     connect(m_doc, SIGNAL(canceled(const QString&)), this, SLOT(slotOpeningFailed(const QString&)));
     if (!m_doc->openURL(url))
