@@ -19,7 +19,7 @@
 #define QUANTA_H
 
 #define QUANTA_PACKAGE "quanta"
-#define QUANTA_VERSION "3.4.1"
+#define QUANTA_VERSION "3.4.2"
 
 #define IDS_STATUS      1
 #define IDS_INS_OVR     2
@@ -169,6 +169,8 @@ public:
       toolbar from the file */
   void showToolbarFile(const KURL &url);
 
+  void setParserEnabled(bool enabled) {m_parserEnabled = enabled;}
+
     /** tabs for left panel */
   DocTreeView *dTab;
   EnhancedTagAttributeTree *aTab;
@@ -577,6 +579,7 @@ private:
   uint oldCursorCol;
   bool m_previewVisible;
   bool m_noFramesPreview;
+  bool m_parserEnabled; ///< enables/disables reparsing. If false, even a forced reparse is ignored (used when opening multiple files)
 
   QString m_scriptOutput;
 
