@@ -29,6 +29,7 @@
 #include <kdebug.h>
 #include <kpopupmenu.h>
 #include <kpropertiesdialog.h>
+#include <ktempfile.h>
 #include <kapplication.h>
 #include <kstringhandler.h>
 
@@ -102,6 +103,7 @@ KFileTreeViewItem* ProjectTreeBranch::createTreeViewItem(KFileTreeViewItem *pare
 ProjectTreeView::ProjectTreeView(QWidget *parent, const char *name )
   : BaseTreeView(parent,name), m_projectFiles(0)
 {
+  //setSelectionModeExt(KListView::Extended);
   setRootIsDecorated(false);
   addColumn(i18n("Project Files"), -1);
   addColumn(i18n("Description"), -1);
@@ -124,35 +126,40 @@ ProjectTreeView::ProjectTreeView(QWidget *parent, const char *name )
   m_fileMenu = new KPopupMenu(this);
 
   m_fileMenu->insertItem(SmallIcon("fileopen"), i18n("&Open"), this, SLOT(slotOpen()));
-  m_fileMenu->insertItem(i18n("Open &With..."), this, SLOT(slotOpenWith()));
   m_openInQuantaId = m_fileMenu->insertItem(i18n("Load Toolbar"), this, SLOT(slotLoadToolbar()));
   m_fileMenu->insertItem(i18n("Insert &Tag"), this, SLOT(slotInsertTag()));
   m_menuClose = m_fileMenu->insertItem(SmallIcon("fileclose"), i18n("Clos&e"), this, SLOT(slotClose()));
   m_fileMenu->insertSeparator();
-  m_fileMenu->insertItem(SmallIcon("editdelete"), i18n("&Delete"), this, SLOT(slotDelete()));
-  m_fileMenu->insertItem( i18n("&Remove From Project"), this, SLOT(slotRemoveFromProject(int)));
   m_fileMenu->insertItem(SmallIcon("up"), i18n("&Upload File..."), this, SLOT(slotUploadSingleURL()));
+  m_fileMenu->insertItem(SmallIcon("up"), i18n("&Quick File Upload"), this, SLOT(slotQuickUploadURL()));
   m_fileMenu->insertItem(i18n("Re&name"), this, SLOT(slotStartRename()));
+  m_fileMenu->insertItem( i18n("&Remove From Project"), this, SLOT(slotRemoveFromProject(int)));
+  m_fileMenu->insertItem(SmallIcon("editdelete"), i18n("&Delete"), this, SLOT(slotDelete()));
   m_fileMenu->insertSeparator();
   m_fileMenu->insertItem(i18n("Upload &Status"), m_uploadStatusMenu);
   m_fileMenu->insertItem(SmallIcon("info"), i18n("&Properties"), this, SLOT(slotProperties()));
 
+  KPopupMenu *createNewMenu = new KPopupMenu(this);
+  createNewMenu->insertItem(SmallIcon("folder_new"), i18n("F&older..."), this, SLOT(slotCreateFolder()));
+  createNewMenu->insertItem(SmallIcon("document"), i18n("&File..."), this, SLOT(slotCreateFile()));
+
   m_folderMenu = new KPopupMenu(this);
 
-  m_folderMenu->insertItem(SmallIcon("folder_new"), i18n("&Create Folder..."), this, SLOT(slotCreateFolder()));
+  m_folderMenu->insertItem(SmallIconSet("filenew"), i18n("&Create New"), createNewMenu);
   m_folderMenu->insertSeparator();
-  m_folderMenu->insertItem(SmallIcon("editdelete"), i18n("&Delete"), this, SLOT(slotDelete()));
-  m_folderMenu->insertItem(i18n("&Remove From Project"), this, SLOT(slotRemoveFromProject(int)));
   m_folderMenu->insertItem(SmallIcon("up"), i18n("&Upload Folder..."), this, SLOT(slotUploadSingleURL()));
+  m_folderMenu->insertItem(SmallIcon("up"), i18n("&Quick Folder Upload"), this, SLOT(slotQuickUploadURL()));
   m_folderMenu->insertItem(i18n("Create Site &Template..."), this, SLOT(slotCreateSiteTemplate()));
   m_folderMenu->insertItem(i18n("Re&name"), this, SLOT(slotStartRename()));
+  m_folderMenu->insertItem(i18n("&Remove From Project"), this, SLOT(slotRemoveFromProject(int)));
+  m_folderMenu->insertItem(SmallIcon("editdelete"), i18n("&Delete"), this, SLOT(slotDelete()));
   m_folderMenu->insertSeparator();
   m_setDocumentRootId = m_folderMenu->insertItem(i18n("Document-&Base Folder"), this, SLOT(slotChangeDocumentFolderStatus()));
   m_folderMenu->insertItem(i18n("Upload &Status"), m_uploadStatusMenu);
   m_folderMenu->insertItem(SmallIcon("info"), i18n("&Properties"), this, SLOT(slotProperties()));
 
   m_projectMenu = new KPopupMenu(this);
-  m_projectMenu->insertItem(SmallIcon("folder_new"), i18n("&Create Folder..."), this, SLOT(slotCreateFolder()));
+  m_projectMenu->insertItem(SmallIconSet("filenew"), i18n("&Create New"), createNewMenu);
   m_projectMenu->insertSeparator();
   m_projectMenu->insertItem(SmallIcon("up"), i18n("&Upload Project..."), this, SLOT(slotUploadProject()));
   m_projectMenu->insertItem(SmallIcon("reload"), i18n("Re&scan Project Folder..."), this, SLOT(slotRescan()));
@@ -223,18 +230,21 @@ void ProjectTreeView::slotMenu(KListView *listView, QListViewItem *item, const Q
   CVSService::ref()->setRepository(m_projectBaseURL.path());
   if (url.isLocalFile())
   {
-    CVSService::ref()->setCurrentFile(url.path());
+    QString path = url.path();
+    if (path == m_projectBaseURL.path())
+      path += "/.";
+    CVSService::ref()->setCurrentFile(path);
   }
   else
     CVSService::ref()->setCurrentFile("");
 #endif
   ProjectTreeViewItem *curItem = static_cast<ProjectTreeViewItem *>(currentKFileTreeViewItem());
-  if ( item && curItem)
+  if (item && curItem)
   {
     setSelected(item, true);
     if (curItem == curItem->branch()->root())
     {
-     m_projectMenu->popup( point);
+      m_projectMenu->popup(point);
     } else
     {
       if (!curItem->isDir())
@@ -247,6 +257,7 @@ void ProjectTreeView::slotMenu(KListView *listView, QListViewItem *item, const Q
           m_fileMenu->setItemVisible(m_openInQuantaId, false);
         }
         m_fileMenu->setItemVisible(m_menuClose, isFileOpen(url));
+        insertOpenWithMenu(m_fileMenu, 1);
         m_fileMenu->popup(point);
       } else
       {
@@ -257,6 +268,11 @@ void ProjectTreeView::slotMenu(KListView *listView, QListViewItem *item, const Q
         m_folderMenu->popup(point);
       }
     }
+  } else
+  if (!m_projectName.isNull())
+  {
+    setSelected(firstChild(), true);
+    m_projectMenu->popup(point);
   }
 }
 
@@ -308,7 +324,10 @@ void ProjectTreeView::slotReloadTree( ProjectList *fileList, bool buildNewTree,
   if (buildNewTree)
   {
     if (m_projectDir)
+    {
       removeBranch(m_projectDir);
+      m_projectDir = 0L;
+    }
     BaseTreeBranch *btb = dynamic_cast<BaseTreeBranch *>(newBranch(m_projectBaseURL));
     if (btb && folderToOpen.count() > 0) {
       btb->folderToOpen = folderToOpen;
@@ -327,6 +346,7 @@ void ProjectTreeView::slotReloadTree( ProjectList *fileList, bool buildNewTree,
         item = dynamic_cast <KFileTreeViewItem*> (iter.current());
         item->setVisible(m_projectFiles->contains(item->url()) || item == rootItem);
       }
+      rootItem->setEnabled(true);
     }
   }
 }
@@ -366,6 +386,34 @@ void ProjectTreeView::slotCreateFolder()
   }
 }
 
+void ProjectTreeView::slotCreateFile()
+{
+  bool ok;
+  QString fileName = KInputDialog::getText(i18n("Create New File"), i18n("File name:"), "", &ok, this);
+  if (ok)
+  {
+    KURL url = currentURL();
+    if (currentKFileTreeViewItem()->isDir())
+      url.setPath(url.path() + "/" + fileName);
+    else
+      url.setPath(url.directory() + "/" + fileName);
+    if (QExtFileInfo::exists(url))
+    {
+      KMessageBox::error(this, i18n("<qt>Cannot create file, because a file named <b>%1</b> already exists.</qt>").arg(fileName), i18n("Error Creating File"));
+      return;
+    }
+    KTempFile *tempFile = new KTempFile(tmpDir);
+    tempFile->setAutoDelete(true);
+    tempFile->close();
+    if (QExtFileInfo::copy(KURL::fromPathOrURL(tempFile->name()), url));
+    {
+      emit insertToProject(url);
+      emit openFile(url);
+    }
+    delete tempFile;
+  }
+}
+
 
 void ProjectTreeView::slotRemoveFromProject(int askForRemove)
 {
@@ -376,7 +424,7 @@ void ProjectTreeView::slotRemoveFromProject(int askForRemove)
     QString nice = QExtFileInfo::toRelative(url, m_projectBaseURL).path();
     nice = KStringHandler::lsqueeze(nice, 60);
     if ( !askForRemove ||
-         KMessageBox::warningYesNo(this,i18n("<qt>Do you really want to remove <br><b>%1</b><br> from the project?</qt>").arg(nice), i18n("Remove From Project"), KStdGuiItem::yes(), KStdGuiItem::no(), "RemoveFromProject") == KMessageBox::Yes )
+         KMessageBox::warningContinueCancel(this,i18n("<qt>Do you really want to remove <br><b>%1</b><br> from the project?</qt>").arg(nice), i18n("Remove From Project"), KStdGuiItem::del(), "RemoveFromProject") == KMessageBox::Continue )
     {
       if ( currentKFileTreeViewItem()->isDir() ) url.adjustPath(+1);
       emit removeFromProject(url);
@@ -391,11 +439,20 @@ void ProjectTreeView::slotUploadSingleURL()
   {
     KURL url = currentURL();
     if ( currentKFileTreeViewItem()->isDir() ) url.adjustPath(+1);
-    emit uploadSingleURL(url);
+    emit uploadSingleURL(url, false);
+  }
+}
+
+void ProjectTreeView::slotQuickUploadURL()
+{
+  if (currentItem())
+  {
+    KURL url = currentURL();
+    if ( currentKFileTreeViewItem()->isDir() ) url.adjustPath(+1);
+    emit uploadSingleURL(url, true);
   }
 }
 
-/** No descriptions */
 void ProjectTreeView::slotRescan()
 {
   emit rescanProjectDir();
@@ -586,6 +643,8 @@ void ProjectTreeView::plugCVSMenu()
   m_fileMenu->insertItem(SmallIcon("cervisia"), i18n("C&VS"), CVSService::ref()->menu());
   m_folderMenu->insertSeparator();
   m_folderMenu->insertItem(SmallIcon("cervisia"), i18n("C&VS"), CVSService::ref()->menu());
+  m_projectMenu->insertSeparator();
+  m_projectMenu->insertItem(SmallIcon("cervisia"), i18n("C&VS"), CVSService::ref()->menu());
 #endif
 
 }
