@@ -38,6 +38,7 @@
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kstandarddirs.h>
+#include <kmainwindow.h>
 #include <kmimetype.h>
 #include <kmessagebox.h>
 #include <kcombobox.h>
@@ -55,15 +56,14 @@
 
 
 #include "templatestreeview.h"
-#include "newtemplatedirdlg.h"
-#include "quantapropertiespage.h"
-#include "tagaction.h"
 #include "copyto.h"
-#include "resource.h"
+#include "newtemplatedirdlg.h"
 #include "qextfileinfo.h"
-#include "quanta.h"
-#include "tagmaildlg.h"
 #include "quantanetaccess.h"
+#include "quantapropertiespage.h"
+#include "resource.h"
+#include "tagaction.h"
+#include "tagmaildlg.h"
 
 #define EXCLUDE ".*\\.tmpl$"
 #define TMPL ".tmpl"
@@ -129,8 +129,8 @@ KFileTreeViewItem* TemplatesTreeBranch::createTreeViewItem(KFileTreeViewItem *pa
 
 
 
-TemplatesTreeView::TemplatesTreeView(QWidget *parent, const char *name )
-  : BaseTreeView(parent,name), m_projectDir(0)
+TemplatesTreeView::TemplatesTreeView(KMainWindow *parent, const char *name )
+  : BaseTreeView(parent,name), m_projectDir(0), m_mainWindow(parent)
 {
   typeToi18n["text/all"] = i18n("Text Snippet");
   typeToi18n["file/all"] = i18n("Binary File");
@@ -141,11 +141,12 @@ TemplatesTreeView::TemplatesTreeView(QWidget *parent, const char *name )
   i18nToType[i18n("Document Template")] = "template/all";
   i18nToType[i18n("Site Template")] = "site/all";
 
-  m_fileMenu = new KPopupMenu();
+  m_fileMenu = new KPopupMenu(this);
 
   m_openId = m_fileMenu->insertItem(i18n("Open"), this ,SLOT(slotInsert()));
   m_fileMenu->insertItem(SmallIcon("fileopen"), i18n("&Open"), this ,SLOT(slotOpen()));
   m_fileMenu->insertItem(SmallIcon("mail_send"), i18n("Send in E&mail..."), this, SLOT(slotSendInMail()));
+  m_fileMenu->insertItem(SmallIcon("network"), i18n("&Upload Template..."), this, SLOT(slotUploadTemplate()));
   m_insertFileInProject = m_fileMenu->insertItem(i18n("&Insert in Project..."), this, SLOT(slotInsertInProject()));
   m_menuClose = m_fileMenu->insertItem(SmallIcon("fileclose"), i18n("Clos&e"), this, SLOT(slotClose()));
   m_fileMenu->insertSeparator();
@@ -154,10 +155,12 @@ TemplatesTreeView::TemplatesTreeView(QWidget *parent, const char *name )
   m_fileMenu->insertSeparator();
   m_fileMenu->insertItem(SmallIcon("info"), i18n("&Properties"), this, SLOT(slotProperties()));
 
-  m_folderMenu = new KPopupMenu();
+  m_folderMenu = new KPopupMenu(this);
 
   m_folderMenu->insertItem(SmallIcon("folder_new"), i18n("&New Folder..."), this, SLOT(slotNewDir()));
   m_folderMenu->insertItem(SmallIcon("mail_send"), i18n("Send in E&mail..."), this, SLOT(slotSendInMail()));
+  m_folderMenu->insertItem(SmallIcon("network"), i18n("&Upload Template..."), this, SLOT(slotUploadTemplate()));
+  m_downloadMenuId = m_folderMenu->insertItem(SmallIcon("network"), i18n("&Download Template..."), this, SIGNAL(downloadTemplate()));
   m_insertFolderInProject = m_folderMenu->insertItem(i18n("&Insert in Project..."), this, SLOT(slotInsertDirInProject()));
   m_folderMenu->insertSeparator();
   m_folderMenu->insertItem(SmallIcon("editcopy"), i18n("&Copy"), this, SLOT(slotCopy()));
@@ -166,7 +169,9 @@ TemplatesTreeView::TemplatesTreeView(QWidget *parent, const char *name )
   m_folderMenu->insertSeparator();
   m_folderMenu->insertItem(SmallIcon("info"), i18n("&Properties"), this, SLOT(slotProperties()));
   m_reloadMenuId = m_folderMenu->insertItem(SmallIcon("revert"), i18n("&Reload"), this, SLOT(slotReload()));
-  m_downloadMenuId = m_folderMenu->insertItem(i18n("Do&wnload Template..."), this, SIGNAL(downloadTemplate()));
+
+  m_emptyAreaMenu = new KPopupMenu(this);
+  m_emptyAreaMenu->insertItem(SmallIcon("network"), i18n("&Download Template..."), this, SIGNAL(downloadTemplate()));
 
   addColumn(i18n("Templates"), -1);
   addColumn(i18n("Group"), -1);
@@ -248,7 +253,11 @@ void TemplatesTreeView::slotInsertInDocument()
 
 void TemplatesTreeView::slotMenu(KListView*, QListViewItem *item, const QPoint &point)
 {
-  if ( !item ) return;
+  if (!item)
+  {
+    m_emptyAreaMenu->popup(point);
+    return;
+  }
   setSelected(item, true);
   bool hasProject = m_projectName;
   m_folderMenu->setItemVisible(m_insertFolderInProject, hasProject);
@@ -632,8 +641,9 @@ void TemplatesTreeView::slotProperties()
   uint j = 1;
   m_quantaProperties->actionCombo->insertItem(i18n(NONE));
   QString tmpStr;
-  KActionCollection *ac = quantaApp->actionCollection();
-  for (uint i = 0; i < ac->count(); i++)
+  KActionCollection *ac = m_mainWindow->actionCollection();
+  uint acCount = ac->count();
+  for (uint i = 0; i < acCount; i++)
   {
     TagAction *action = dynamic_cast<TagAction*>(ac->action(i));
     if (action)
@@ -755,19 +765,20 @@ void TemplatesTreeView::slotDragInsert(QDropEvent *e)
     return;
 
    KURL url = fileList.front();
-   if(!url.isLocalFile())
-    return;
 
-   QString localFileName = url.path();
-
-   m_dirInfo = readDirInfo(localFileName);
-   QString mimeType = KMimeType::findByPath(localFileName)->name();
+   QString localFileName;
+   if (url.isLocalFile()) 
+   {
+     localFileName = url.path();
+     m_dirInfo = readDirInfo(localFileName);
+   }
+   QString mimeType = KMimeType::findByURL(url)->name();
 
    /* First, see if the type of the file is specified in the .dirinfo file */
    if(m_dirInfo.mimeType.isEmpty())
    {
      // no .dirinfo file present, so we insert it as tag
-     emit insertTag(KURL::fromPathOrURL( localFileName ), m_dirInfo);
+     emit insertTag(url, m_dirInfo);
    } else
    {
      if(m_dirInfo.mimeType == "text/all") // default to inserting in document
@@ -866,7 +877,7 @@ void TemplatesTreeView::slotDelete()
     else
       msg = i18n("Do you really want to delete file \n%1 ?\n").arg(url.path());
 
-    if ( KMessageBox::warningYesNo(this, msg) == KMessageBox::Yes )
+    if ( KMessageBox::warningContinueCancel(this, msg, QString::null, KStdGuiItem::del()) == KMessageBox::Continue )
     {
       KIO::Job *job = KIO::del(url);
       connect( job, SIGNAL( result( KIO::Job *) ), this , SLOT( slotJobFinished( KIO::Job *) ) );
@@ -889,9 +900,10 @@ KURL TemplatesTreeView::filterTemplate()
  config.setGroup("Filtering");
  name = config.readEntry("Action", NONE);
  TagAction *filterAction = 0L;
- KActionCollection *ac = quantaApp->actionCollection();
+ KActionCollection *ac = m_mainWindow->actionCollection();
+ uint acCount = ac->count();
  QString tmpStr;
- for (uint i = 0; i < ac->count(); i++)
+ for (uint i = 0; i < acCount; i++)
  {
    TagAction *action = dynamic_cast<TagAction*>(ac->action(i));
    if (action)
@@ -921,48 +933,54 @@ KURL TemplatesTreeView::filterTemplate()
  return url;
 }
 
+QString TemplatesTreeView::createTemplateTarball()
+{
+  KURL url = currentURL();
+  KURL dirURL (url);
+  if (!currentKFileTreeViewItem()->isDir())
+    dirURL.setPath(dirURL.directory(false));
+
+  KTempDir* tempDir = new KTempDir(tmpDir);
+  tempDir->setAutoDelete(true);
+  tempDirList.append(tempDir);
+  QString tempFileName=tempDir->name() + url.fileName() + ".tgz";
+  //pack the files into a .tgz file
+  KTar tar(tempFileName, "application/x-gzip");
+  tar.open(IO_WriteOnly);
+//    tar.setOrigFileName("");
+
+  KURL::List files;
+  if ( ! currentKFileTreeViewItem()->isDir() )
+    files.append(url);
+  else {
+    files = QExtFileInfo::allFiles(dirURL, "*") ;
+    dirURL = dirURL.upURL();
+  }
+
+  for ( KURL::List::Iterator it_f = files.begin(); it_f != files.end(); ++it_f )
+  {
+    if (!(*it_f).fileName(false).isEmpty()) {
+      url = QExtFileInfo::toRelative( (*it_f), dirURL) ;
+
+      QFile file((*it_f).path());
+      file.open(IO_ReadOnly);
+      QByteArray bArray = file.readAll();
+      tar.writeFile(url.path(), "user", "group", bArray.size(), bArray.data());
+      file.close();
+    };
+  }
+  tar.close();
+
+  return tempFileName;
+}
 
 void TemplatesTreeView::slotSendInMail()
 {
   if ( ! currentKFileTreeViewItem() ) return;
 
-    KURL url = currentURL();
-    KURL dirURL (url);
-    dirURL.setPath(dirURL.directory(false));
-
-    KTempDir* tempDir = new KTempDir(tmpDir);
-    tempDir->setAutoDelete(true);
-    tempDirList.append(tempDir);
-    QString tempFileName=tempDir->name() + url.fileName() + ".tgz";
-  //pack the files into a .tgz file
-    KTar tar(tempFileName, "application/x-gzip");
-    tar.open(IO_WriteOnly);
-//    tar.setOrigFileName("");
-
-    KURL::List files;
-    if ( ! currentKFileTreeViewItem()->isDir() )
-      files.append(url);
-    else {
-      files = QExtFileInfo::allFiles(dirURL, "*") ;
-      dirURL = dirURL.upURL();
-    }
-
-    for ( KURL::List::Iterator it_f = files.begin(); it_f != files.end(); ++it_f )
-    {
-      if ( (*it_f).fileName(false) != "" ) {
-        url = QExtFileInfo::toRelative( (*it_f), dirURL) ;
-
-        QFile file((*it_f).path());
-        file.open(IO_ReadOnly);
-        QByteArray bArray = file.readAll();
-        tar.writeFile(url.path(), "user", "group", bArray.size(), bArray.data());
-        file.close();
-      };
-    }
-    tar.close();
 
     QStringList attachmentFile;
-    attachmentFile += tempFileName;
+    attachmentFile += createTemplateTarball();
 
     TagMailDlg *mailDlg = new TagMailDlg( this, i18n("Send template in email"));
     QString toStr;
@@ -993,6 +1011,12 @@ void TemplatesTreeView::slotSendInMail()
     delete mailDlg;
 }
 
+void TemplatesTreeView::slotUploadTemplate()
+{
+  if ( ! currentKFileTreeViewItem() ) return;
+  emit uploadTemplate(createTemplateTarball());
+}
+
 bool TemplatesTreeView::acceptDrag(QDropEvent* e ) const
 {
  return (BaseTreeView::acceptDrag(e) || QTextDrag::canDecode(e));
