@@ -376,7 +376,7 @@ QString QuantaCommon::qUrl(const KURL &url)
 /** No descriptions */
 void QuantaCommon::dirCreationError(QWidget *widget, const KURL& url)
 {
-  KMessageBox::error(widget, i18n("<qt>Cannot create directory<br><b>%1</b>.<br>Check that you have write permission in the parent directory or that the connection to<br><b>%2</b><br> is valid.</qt>")
+  KMessageBox::error(widget, i18n("<qt>Cannot create folder<br><b>%1</b>.<br>Check that you have write permission in the parent folder or that the connection to<br><b>%2</b><br> is valid.</qt>")
                              .arg(url.prettyURL(0, KURL::StripFileProtocol))
                              .arg(url.protocol()+"://"+url.user()+"@"+url.host()));}
 
@@ -682,3 +682,5 @@ bool QuantaCommon::checkOverwrite(const KURL& url)
 
   return result;
 }
+
+
